import { AnnotationLayer, type Axis, type CreatePlotElementOptions, type DataPoint, type IRenderContext, type IXyAxisPlotElement, type OxyRect, PlotElement, type ScreenPoint } from '..';
export interface CreateAnnotationOptions extends CreatePlotElementOptions {
    xAxisKey?: string;
    yAxisKey?: string;
    layer?: AnnotationLayer;
    clipByXAxis?: boolean;
    clipByYAxis?: boolean;
    xAxis?: Axis;
    yAxis?: Axis;
}
export declare const DefaultAnnotationOptions: CreateAnnotationOptions;
export declare const ExtendedDefaultAnnotationOptions: {
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: Axis | undefined;
    yAxis?: Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Provides an abstract base class for annotations.
 */
export declare abstract class Annotation extends PlotElement implements IXyAxisPlotElement {
    /**
     * The rendering layer of the annotation. The default value is AnnotationLayer.AboveSeries.
     */
    layer: AnnotationLayer;
    private _xAxis?;
    /**
     * The X axis.
     */
    get xAxis(): Axis | undefined;
    /**
     * The X axis key.
     */
    xAxisKey?: string;
    private _yAxis?;
    /**
     * The Y axis.
     */
    get yAxis(): Axis | undefined;
    /**
     * A value indicating whether to clip the annotation by the X axis range.
     */
    clipByXAxis: boolean;
    /**
     * A value indicating whether to clip the annotation by the Y axis range.
     */
    clipByYAxis: boolean;
    /**
     * The Y axis key.
     */
    yAxisKey?: string;
    /**
     * Initializes a new instance of the Annotation class.
     */
    protected constructor(opt?: CreateAnnotationOptions);
    /**
     * Ensures that the annotation axes are set.
     */
    ensureAxes(): void;
    /**
     * Renders the annotation on the specified context.
     * @param rc The render context.
     */
    abstract render(rc: IRenderContext): Promise<void>;
    /**
     * Gets the clipping rect.
     */
    getClippingRect(): OxyRect;
    /**
     * Transforms the data point.
     * @param p The data point.
     */
    transform(p: DataPoint): ScreenPoint;
    /**
     * Inverse transforms the screen point.
     * @param p The screen point.
     */
    inverseTransform(p: ScreenPoint): DataPoint;
}
//# sourceMappingURL=Annotation.d.ts.map