import { type CreateTextualAnnotationOptions, type DataPoint, HitTestArguments, type HitTestResult, HorizontalAlignment, type IRenderContext, LineJoin, LineStyle, type OxyColor, type ScreenVector, TextualAnnotation, VerticalAlignment } from '..';
export interface CreateArrowAnnotationOptions extends CreateTextualAnnotationOptions {
    arrowDirection?: ScreenVector;
    color?: OxyColor;
    endPoint?: DataPoint;
    headLength?: number;
    headWidth?: number;
    lineJoin?: LineJoin;
    lineStyle?: LineStyle;
    startPoint?: DataPoint;
    strokeThickness?: number;
    veeness?: number;
}
export declare const DefaultArrowAnnotationOptions: CreateArrowAnnotationOptions;
export declare const ExtendedDefaultArrowAnnotationOptions: {
    arrowDirection?: ScreenVector | undefined;
    color?: string | undefined;
    endPoint?: DataPoint | undefined;
    headLength?: number | undefined;
    headWidth?: number | undefined;
    lineJoin?: LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    startPoint?: DataPoint | undefined;
    strokeThickness?: number | undefined;
    veeness?: number | undefined;
    text?: string | undefined;
    textPosition?: DataPoint | undefined;
    textHorizontalAlignment?: HorizontalAlignment | undefined;
    textVerticalAlignment?: VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows an arrow.
 */
export declare class ArrowAnnotation extends TextualAnnotation {
    /**
     * The end point in screen coordinates.
     */
    private _screenEndPoint;
    /**
     * The start point in screen coordinates.
     */
    private _screenStartPoint;
    /**
     * Initializes a new instance of the ArrowAnnotation class.
     */
    constructor(opt?: CreateArrowAnnotationOptions);
    getElementName(): string;
    /**
     * Gets or sets the arrow direction.
     * Setting this property overrides the StartPoint property.
     */
    arrowDirection: ScreenVector;
    /**
     * Gets or sets the color of the arrow.
     */
    color: OxyColor;
    /**
     * Gets or sets the end point of the arrow.
     */
    endPoint: DataPoint;
    /**
     * Gets or sets the length of the head (relative to the stroke thickness) (the default value is 10).
     */
    headLength: number;
    /**
     * Gets or sets the width of the head (relative to the stroke thickness) (the default value is 3).
     */
    headWidth: number;
    /**
     * Gets or sets the line join type.
     */
    lineJoin: LineJoin;
    /**
     * Gets or sets the line style.
     */
    lineStyle: LineStyle;
    /**
     * Gets or sets the start point of the arrow.
     * This property is overridden by the ArrowDirection property, if set.
     */
    startPoint: DataPoint;
    /**
     * Gets or sets the stroke thickness (the default value is 2).
     */
    strokeThickness: number;
    /**
     * Gets or sets the 'veeness' of the arrow head (relative to thickness) (the default value is 0).
     */
    veeness: number;
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     * @param args The hit test arguments.
     * @returns The result of the hit test.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=ArrowAnnotation.d.ts.map