import { type CreateShapeAnnotationOptions, HitTestArguments, type HitTestResult, type IRenderContext, ShapeAnnotation } from '..';
export interface CreateEllipseAnnotationOptions extends CreateShapeAnnotationOptions {
    x?: number;
    y?: number;
    width?: number;
    height?: number;
}
export declare const DefaultEllipseAnnotationOptions: CreateEllipseAnnotationOptions;
export declare const ExtendedDefaultEllipseAnnotationOptions: {
    x?: number | undefined;
    y?: number | undefined;
    width?: number | undefined;
    height?: number | undefined;
    fill?: string | undefined;
    stroke?: string | undefined;
    strokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: import('..').DataPoint | undefined;
    textHorizontalAlignment?: import('..').HorizontalAlignment | undefined;
    textVerticalAlignment?: import('..').VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows an ellipse.
 */
export declare class EllipseAnnotation extends ShapeAnnotation {
    /**
     * The rectangle transformed to screen coordinates.
     */
    private _screenRectangle;
    /**
     * Initializes a new instance of the EllipseAnnotation class.
     */
    constructor(opt?: CreateEllipseAnnotationOptions);
    getElementName(): string;
    /**
     * The x-coordinate of the center.
     */
    x: number;
    /**
     * The y-coordinate of the center.
     */
    y: number;
    /**
     * The width of the ellipse.
     */
    width: number;
    /**
     * The height of the ellipse.
     */
    height: number;
    /**
     * Renders the ellipse annotation.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=EllipseAnnotation.d.ts.map