import { type CreatePathAnnotationOptions, type DataPoint, PathAnnotation, type PlotModelSerializeOptions, type ScreenPoint } from '..';
/**
 * Defines the definition of function in a FunctionAnnotation.
 */
export declare enum FunctionAnnotationType {
    /**
     * Curve equation x=f(y) given by the Equation property
     */
    EquationX = 0,
    /**
     * Curve equation y=f(x) given by the Equation property
     */
    EquationY = 1
}
export interface CreateFunctionAnnotationOptions extends CreatePathAnnotationOptions {
    equation?: (arg: number) => number;
    resolution?: number;
    type?: FunctionAnnotationType;
}
export declare const DefaultFunctionAnnotationOptions: CreateFunctionAnnotationOptions;
export declare const ExtendedDefaultFunctionAnnotationOptions: {
    equation?: ((arg: number) => number) | undefined;
    resolution?: number | undefined;
    type?: FunctionAnnotationType | undefined;
    minimumX?: number | undefined;
    maximumX?: number | undefined;
    minimumY?: number | undefined;
    maximumY?: number | undefined;
    color?: string | undefined;
    strokeThickness?: number | undefined;
    lineStyle?: import('..').LineStyle | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    textLinePosition?: number | undefined;
    textOrientation?: import('..').AnnotationTextOrientation | undefined;
    textMargin?: number | undefined;
    minimumSegmentLength?: number | undefined;
    textPadding?: number | undefined;
    borderPadding?: import('..').OxyThickness | undefined;
    borderBackground?: string | undefined;
    borderStroke?: string | undefined;
    borderStrokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: DataPoint | undefined;
    textHorizontalAlignment?: import('..').HorizontalAlignment | undefined;
    textVerticalAlignment?: import('..').VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows a function rendered as a path.
 */
export declare class FunctionAnnotation extends PathAnnotation {
    /**
     * Initializes a new instance of the FunctionAnnotation class.
     */
    constructor(opt?: CreateFunctionAnnotationOptions);
    getElementName(): string;
    /**
     * The type of function. Can be either f(x) or f(y).
     */
    type: FunctionAnnotationType;
    /**
     * The y=f(x) equation when type is Equation.
     */
    equation?: (arg: number) => number;
    /**
     * The resolution.
     */
    resolution: number;
    /**
     * Gets the screen points.
     */
    protected getScreenPoints(): ScreenPoint[];
    protected getElementDefaultValues(): any;
    toJSON(opt?: PlotModelSerializeOptions): any;
}
//# sourceMappingURL=FunctionAnnotation.d.ts.map