import { type CreateTransposableAnnotationOptions, HitTestArguments, type HitTestResult, HorizontalAlignment, type IRenderContext, type OxyImage, type OxyRect, type PlotLength, type ScreenPoint, type ScreenVector, TransposableAnnotation, VerticalAlignment } from '..';
export interface CreateImageAnnotationOptions extends CreateTransposableAnnotationOptions {
    imageSource?: OxyImage;
    horizontalAlignment?: HorizontalAlignment;
    x?: PlotLength;
    y?: PlotLength;
    offsetX?: PlotLength;
    offsetY?: PlotLength;
    width?: PlotLength;
    height?: PlotLength;
    opacity?: number;
    interpolate?: boolean;
    verticalAlignment?: VerticalAlignment;
}
export declare const DefaultImageAnnotationOptions: CreateImageAnnotationOptions;
export declare const ExtendedDefaultImageAnnotationOptions: {
    imageSource?: OxyImage | undefined;
    horizontalAlignment?: HorizontalAlignment | undefined;
    x?: PlotLength | undefined;
    y?: PlotLength | undefined;
    offsetX?: PlotLength | undefined;
    offsetY?: PlotLength | undefined;
    width?: PlotLength | undefined;
    height?: PlotLength | undefined;
    opacity?: number | undefined;
    interpolate?: boolean | undefined;
    verticalAlignment?: VerticalAlignment | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows an image.
 */
export declare class ImageAnnotation extends TransposableAnnotation {
    /**
     * The actual bounds of the rendered image.
     */
    private actualBounds;
    constructor(opt?: CreateImageAnnotationOptions);
    getElementName(): string;
    /**
     * Gets or sets the image source.
     */
    imageSource?: OxyImage;
    /**
     * Gets or sets the X position of the image.
     */
    x: PlotLength;
    /**
     * Gets or sets the Y position of the image.
     */
    y: PlotLength;
    /**
     * Gets or sets the X offset.
     */
    offsetX: PlotLength;
    /**
     * Gets or sets the Y offset.
     */
    offsetY: PlotLength;
    /**
     * Gets or sets the width.
     */
    width: PlotLength;
    /**
     * Gets or sets the height.
     */
    height: PlotLength;
    /**
     * Gets or sets the opacity (0-1).
     */
    opacity: number;
    /**
     * Gets or sets a value indicating whether to apply smooth interpolation to the image.
     */
    interpolate: boolean;
    /**
     * Gets or sets the horizontal alignment.
     */
    horizontalAlignment: HorizontalAlignment;
    /**
     * Gets or sets the vertical alignment.
     */
    verticalAlignment: VerticalAlignment;
    render(rc: IRenderContext): Promise<void>;
    /**
     * When overridden in a derived class, tests if the plot element is hit by the specified point.
     * @param args The hit test arguments.
     */
    hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    /**
     * Gets the point.
     * @returns The point in screen coordinates.
     */
    getPoint(x: PlotLength, y: PlotLength, model: any): ScreenPoint;
    getVector(x: PlotLength, y: PlotLength, model: any): ScreenVector;
    getClippingRect(): OxyRect;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=ImageAnnotation.d.ts.map