import { type CreatePathAnnotationOptions, type DataPoint, PathAnnotation, type ScreenPoint } from '..';
/**
 * Specifies the definition of the line in a LineAnnotation.
 */
export declare enum LineAnnotationType {
    /**
     * Horizontal line given by the Y property
     */
    Horizontal = 0,
    /**
     * Vertical line given by the X property
     */
    Vertical = 1,
    /**
     * Linear equation y=mx+b given by the Slope and Intercept properties
     */
    LinearEquation = 2
}
export interface CreateLineAnnotationOptions extends CreatePathAnnotationOptions {
    intercept?: number;
    slope?: number;
    type?: LineAnnotationType;
    x?: number;
    y?: number;
}
export declare const DefaultLineAnnotationOptions: CreateLineAnnotationOptions;
export declare const ExtendedDefaultLineAnnotationOptions: {
    intercept?: number | undefined;
    slope?: number | undefined;
    type?: LineAnnotationType | undefined;
    x?: number | undefined;
    y?: number | undefined;
    minimumX?: number | undefined;
    maximumX?: number | undefined;
    minimumY?: number | undefined;
    maximumY?: number | undefined;
    color?: string | undefined;
    strokeThickness?: number | undefined;
    lineStyle?: import('..').LineStyle | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    textLinePosition?: number | undefined;
    textOrientation?: import('..').AnnotationTextOrientation | undefined;
    textMargin?: number | undefined;
    minimumSegmentLength?: number | undefined;
    textPadding?: number | undefined;
    borderPadding?: import('..').OxyThickness | undefined;
    borderBackground?: string | undefined;
    borderStroke?: string | undefined;
    borderStrokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: DataPoint | undefined;
    textHorizontalAlignment?: import('..').HorizontalAlignment | undefined;
    textVerticalAlignment?: import('..').VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows a straight line.
 */
export declare class LineAnnotation extends PathAnnotation {
    /**
     * Initializes a new instance of the LineAnnotation class.
     */
    constructor(opt?: CreateLineAnnotationOptions);
    getElementName(): string;
    /**
     * The y-intercept when type is LinearEquation.
     */
    intercept: number;
    /**
     * The slope when type is LinearEquation.
     */
    slope: number;
    /**
     * The type of line equation.
     */
    type: LineAnnotationType;
    /**
     * The X position for vertical lines (only for type==Vertical).
     */
    x: number;
    /**
     * The Y position for horizontal lines (only for type==Horizontal)
     */
    y: number;
    /**
     * Gets the screen points.
     */
    protected getScreenPoints(): ScreenPoint[];
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=LineAnnotation.d.ts.map