import { AnnotationTextOrientation, type CreateTextualAnnotationOptions, HitTestArguments, type HitTestResult, HorizontalAlignment, type IRenderContext, LineJoin, LineStyle, type OxyColor, type OxyThickness, type ScreenPoint, TextualAnnotation, VerticalAlignment } from '..';
export interface CreatePathAnnotationOptions extends CreateTextualAnnotationOptions {
    minimumX?: number;
    maximumX?: number;
    minimumY?: number;
    maximumY?: number;
    color?: OxyColor;
    strokeThickness?: number;
    lineStyle?: LineStyle;
    lineJoin?: LineJoin;
    textLinePosition?: number;
    textOrientation?: AnnotationTextOrientation;
    textMargin?: number;
    minimumSegmentLength?: number;
    textPadding?: number;
    borderPadding?: OxyThickness;
    borderBackground?: OxyColor;
    borderStroke?: OxyColor;
    borderStrokeThickness?: number;
}
export declare const DefaultPathAnnotationOptions: CreatePathAnnotationOptions;
export declare const ExtendedDefaultPathAnnotationOptions: {
    minimumX?: number | undefined;
    maximumX?: number | undefined;
    minimumY?: number | undefined;
    maximumY?: number | undefined;
    color?: string | undefined;
    strokeThickness?: number | undefined;
    lineStyle?: LineStyle | undefined;
    lineJoin?: LineJoin | undefined;
    textLinePosition?: number | undefined;
    textOrientation?: AnnotationTextOrientation | undefined;
    textMargin?: number | undefined;
    minimumSegmentLength?: number | undefined;
    textPadding?: number | undefined;
    borderPadding?: OxyThickness | undefined;
    borderBackground?: string | undefined;
    borderStroke?: string | undefined;
    borderStrokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: import('..').DataPoint | undefined;
    textHorizontalAlignment?: HorizontalAlignment | undefined;
    textVerticalAlignment?: VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows a function rendered as a path.
 */
export declare abstract class PathAnnotation extends TextualAnnotation {
    /**
     * The points of the line, transformed to screen coordinates.
     */
    private _screenPoints?;
    /**
     * Initializes a new instance of the PathAnnotation class.
     */
    protected constructor(opt?: CreatePathAnnotationOptions);
    /**
     * The color of the line.
     */
    color: OxyColor;
    /**
     * The line join.
     */
    lineJoin: LineJoin;
    /**
     * The line style.
     */
    lineStyle: LineStyle;
    /**
     * The maximum X coordinate for the line.
     */
    maximumX: number;
    /**
     * The maximum Y coordinate for the line.
     */
    maximumY: number;
    /**
     * The minimum X coordinate for the line.
     */
    minimumX: number;
    /**
     * The minimum Y coordinate for the line.
     */
    minimumY: number;
    /**
     * The stroke thickness.
     */
    strokeThickness: number;
    /**
     * The text margin (along the line).
     */
    textMargin: number;
    /**
     * The text padding (in the direction of the text).
     */
    textPadding: number;
    /**
     * The padding of the border rectangle.
     */
    borderPadding: OxyThickness;
    /**
     * The fill color of the border rectangle.
     */
    borderBackground: OxyColor;
    /**
     * The stroke color of the border rectangle.
     */
    borderStroke: OxyColor;
    /**
     * The stroke thickness of the border rectangle.
     */
    borderStrokeThickness: number;
    /**
     * The text orientation.
     */
    textOrientation: AnnotationTextOrientation;
    /**
     * The text position relative to the line.
     */
    textLinePosition: number;
    /**
     * The minimum length of the segment.
     */
    minimumSegmentLength: number;
    /**
     * The actual minimum value on the x-axis.
     */
    protected actualMinimumX: number;
    /**
     * The actual minimum value on the y-axis.
     */
    protected actualMinimumY: number;
    /**
     * The actual maximum value on the x-axis.
     */
    protected actualMaximumX: number;
    /**
     * The actual maximum value on the y-axis.
     */
    protected actualMaximumY: number;
    /**
     * Renders the path annotation.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    /**
     * Gets the screen points.
     */
    protected abstract getScreenPoints(): ScreenPoint[];
    /**
     * Calculates the actual minimums and maximums.
     */
    protected calculateActualMinimumsMaximums(): void;
    /**
     * Gets the point on a curve at the specified relative distance along the curve.
     */
    private static getPointAtRelativeDistance;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=PathAnnotation.d.ts.map