import { type CreateShapeAnnotationOptions, HitTestArguments, type HitTestResult, type IRenderContext, MarkerType, type ScreenPoint, ShapeAnnotation, VerticalAlignment } from '..';
export interface CreatePointAnnotationOptions extends CreateShapeAnnotationOptions {
    x?: number;
    y?: number;
    size?: number;
    textMargin?: number;
    shape?: MarkerType;
    customOutline?: ScreenPoint[];
}
export declare const DefaultPointAnnotationOptions: CreatePointAnnotationOptions;
export declare const ExtendedDefaultPointAnnotationOptions: {
    x?: number | undefined;
    y?: number | undefined;
    size?: number | undefined;
    textMargin?: number | undefined;
    shape?: MarkerType | undefined;
    customOutline?: ScreenPoint[] | undefined;
    fill?: string | undefined;
    stroke?: string | undefined;
    strokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: import('..').DataPoint | undefined;
    textHorizontalAlignment?: import('..').HorizontalAlignment | undefined;
    textVerticalAlignment?: VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows a point.
 */
export declare class PointAnnotation extends ShapeAnnotation {
    /**
     * The position transformed to screen coordinates.
     */
    private _screenPosition;
    /**
     * Initializes a new instance of the PointAnnotation class.
     */
    constructor(opt?: CreatePointAnnotationOptions);
    getElementName(): string;
    /**
     * The x-coordinate of the center.
     */
    x: number;
    /**
     * The y-coordinate of the center.
     */
    y: number;
    /**
     * The size of the rendered point.
     */
    size: number;
    /**
     * The distance between the rendered point and the text.
     */
    textMargin: number;
    /**
     * The shape of the rendered point.
     */
    shape: MarkerType;
    /**
     * A custom polygon outline for the point marker. Set shape to MarkerType.Custom to use this property.
     */
    customOutline?: ScreenPoint[];
    /**
     * Renders the point annotation.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=PointAnnotation.d.ts.map