import { type CreateShapeAnnotationOptions, type DataPoint, HitTestArguments, type HitTestResult, type IRenderContext, LineJoin, LineStyle, ShapeAnnotation } from '..';
export interface CreatePolygonAnnotationOptions extends CreateShapeAnnotationOptions {
    /**
     * The line join.
     */
    lineJoin?: LineJoin;
    /**
     * The line style.
     */
    lineStyle?: LineStyle;
    /**
     * The minimum length of the segment.
     */
    minimumSegmentLength?: number;
    /**
     * The points.
     */
    points?: DataPoint[];
}
export declare const DefaultPolygonAnnotationOptions: CreatePolygonAnnotationOptions;
export declare const ExtendedDefaultPolygonAnnotationOptions: {
    /**
     * The line join.
     */
    lineJoin?: LineJoin | undefined;
    /**
     * The line style.
     */
    lineStyle?: LineStyle | undefined;
    /**
     * The minimum length of the segment.
     */
    minimumSegmentLength?: number | undefined;
    /**
     * The points.
     */
    points?: DataPoint[] | undefined;
    fill?: string | undefined;
    stroke?: string | undefined;
    strokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: DataPoint | undefined;
    textHorizontalAlignment?: import('..').HorizontalAlignment | undefined;
    textVerticalAlignment?: import('..').VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows a polygon.
 */
export declare class PolygonAnnotation extends ShapeAnnotation {
    /**
     * The polygon points transformed to screen coordinates.
     */
    private _screenPoints;
    /**
     * Initializes a new instance of the PolygonAnnotation class.
     */
    constructor(opt?: CreatePolygonAnnotationOptions);
    getElementName(): string;
    /**
     * The line join.
     */
    lineJoin: LineJoin;
    /**
     * The line style.
     */
    lineStyle: LineStyle;
    /**
     * The minimum length of the segment.
     */
    minimumSegmentLength: number;
    /**
     * The points.
     */
    points: DataPoint[];
    /**
     * Renders the polygon annotation.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=PolygonAnnotation.d.ts.map