import { type CreateShapeAnnotationOptions, EdgeRenderingMode, HitTestArguments, type HitTestResult, type IRenderContext, ShapeAnnotation } from '..';
export interface RectangleAnnotationOptions extends CreateShapeAnnotationOptions {
    minimumX?: number;
    maximumX?: number;
    minimumY?: number;
    maximumY?: number;
}
export declare const DefaultRectangleAnnotationOptions: RectangleAnnotationOptions;
export declare const ExtendedDefaultRectangleAnnotationOptions: {
    minimumX?: number | undefined;
    maximumX?: number | undefined;
    minimumY?: number | undefined;
    maximumY?: number | undefined;
    fill?: string | undefined;
    stroke?: string | undefined;
    strokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: import('..').DataPoint | undefined;
    textHorizontalAlignment?: import('..').HorizontalAlignment | undefined;
    textVerticalAlignment?: import('..').VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows a rectangle.
 */
export declare class RectangleAnnotation extends ShapeAnnotation {
    /**
     * The rectangle transformed to screen coordinates.
     */
    private _screenRectangle;
    /**
     * Initializes a new instance of the RectangleAnnotation class.
     */
    constructor(opt?: RectangleAnnotationOptions);
    getElementName(): string;
    /**
     * The minimum X.
     */
    minimumX: number;
    /**
     * The maximum X.
     */
    maximumX: number;
    /**
     * The minimum Y.
     */
    minimumY: number;
    /**
     * The maximum Y.
     */
    maximumY: number;
    /**
     * Renders the rectangle annotation.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=RectangleAnnotation.d.ts.map