import { type CreateTextualAnnotationOptions, HitTestArguments, type HitTestResult, HorizontalAlignment, type IRenderContext, type OxyColor, type OxySize, type OxyThickness, type ScreenPoint, type ScreenVector, TextualAnnotation, VerticalAlignment } from '..';
export interface CreateTextAnnotationOptions extends CreateTextualAnnotationOptions {
    background?: OxyColor;
    offset?: ScreenVector;
    padding?: OxyThickness;
    stroke?: OxyColor;
    strokeThickness?: number;
}
export declare const DefaultTextAnnotationOptions: CreateTextAnnotationOptions;
export declare const ExtendedDefaultTextAnnotationOptions: {
    background?: string | undefined;
    offset?: ScreenVector | undefined;
    padding?: OxyThickness | undefined;
    stroke?: string | undefined;
    strokeThickness?: number | undefined;
    text?: string | undefined;
    textPosition?: import('..').DataPoint | undefined;
    textHorizontalAlignment?: HorizontalAlignment | undefined;
    textVerticalAlignment?: VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an annotation that shows text.
 */
export declare class TextAnnotation extends TextualAnnotation {
    /**
     * The actual bounds of the text.
     */
    private _actualBounds?;
    /**
     * Initializes a new instance of the TextAnnotation class.
     */
    constructor(opt?: CreateTextAnnotationOptions);
    getElementName(): string;
    /**
     * The fill color of the background rectangle.
     */
    background: OxyColor;
    /**
     * The position offset (screen coordinates).
     */
    offset: ScreenVector;
    /**
     * The padding of the background rectangle.
     */
    padding: OxyThickness;
    /**
     * The stroke color of the background rectangle.
     */
    stroke: OxyColor;
    /**
     * The stroke thickness of the background rectangle.
     */
    strokeThickness: number;
    /**
     * Renders the text annotation.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Tests if the plot element is hit by the specified point.
     */
    protected hitTestOverride(args: HitTestArguments): HitTestResult | undefined;
    /**
     * Gets the coordinates of the (rotated) background rectangle.
     * @internal
     */
    static getTextBounds(position: ScreenPoint, size: OxySize, padding: OxyThickness, rotation: number, horizontalAlignment: HorizontalAlignment, verticalAlignment: VerticalAlignment): ScreenPoint[];
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=TextAnnotation.d.ts.map