import { type CreateTransposableAnnotationOptions, type DataPoint, HorizontalAlignment, type ScreenPoint, TransposableAnnotation, VerticalAlignment } from '..';
export interface CreateTextualAnnotationOptions extends CreateTransposableAnnotationOptions {
    text?: string;
    textPosition?: DataPoint;
    textHorizontalAlignment?: HorizontalAlignment;
    textVerticalAlignment?: VerticalAlignment;
    textRotation?: number;
}
export declare const DefaultTextualAnnotationOptions: CreateTextualAnnotationOptions;
export declare const ExtendedDefaultTextualAnnotationOptions: {
    text?: string | undefined;
    textPosition?: DataPoint | undefined;
    textHorizontalAlignment?: HorizontalAlignment | undefined;
    textVerticalAlignment?: VerticalAlignment | undefined;
    textRotation?: number | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Provides an abstract base class for annotations that contains text.
 */
export declare abstract class TextualAnnotation extends TransposableAnnotation {
    /**
     * Initializes a new instance of the TextualAnnotation class.
     */
    protected constructor(opt?: CreateTextualAnnotationOptions);
    /**
     * Gets or sets the annotation text.
     */
    text?: string;
    /**
     * Gets or sets the position of the text.
     * If the value is DataPoint.Undefined, the default position of the text will be used.
     */
    textPosition: DataPoint;
    /**
     * Gets or sets the horizontal alignment of the text.
     */
    textHorizontalAlignment: HorizontalAlignment;
    /**
     * Gets or sets the vertical alignment of the text.
     */
    textVerticalAlignment: VerticalAlignment;
    /**
     * Gets or sets the rotation of the text.
     * The text rotation in degrees.
     */
    textRotation: number;
    /**
     * Gets the actual position of the text.
     * @param defaultPosition A function that returns the default position. This is used if TextPosition is undefined.
     * @returns The actual position of the text, in screen space.
     */
    protected getActualTextPosition(defaultPosition: () => ScreenPoint): ScreenPoint;
    /**
     * Gets the actual text alignment.
     */
    protected getActualTextAlignment(): [HorizontalAlignment, VerticalAlignment];
}
//# sourceMappingURL=TextualAnnotation.d.ts.map