import { Annotation, type CreateAnnotationOptions, type DataPoint, type ITransposablePlotElement, type OxyRect, type ScreenPoint } from '..';
export type CreateTransposableAnnotationOptions = CreateAnnotationOptions;
export declare const DefaultTransposableAnnotationOptions: CreateTransposableAnnotationOptions;
export declare const ExtendedDefaultTransposableAnnotationOptions: {
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    layer?: import('..').AnnotationLayer | undefined;
    clipByXAxis?: boolean | undefined;
    clipByYAxis?: boolean | undefined;
    xAxis?: import('..').Axis | undefined;
    yAxis?: import('..').Axis | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Provides an abstract base class for transposable annotations.
 */
export declare abstract class TransposableAnnotation extends Annotation implements ITransposablePlotElement {
    protected constructor(opt?: CreateTransposableAnnotationOptions);
    /**
     * Gets the clipping rectangle.
     */
    getClippingRect(): OxyRect;
    /**
     * Transforms the specified data point to a screen point.
     * @param p The data point.
     */
    transform(p: DataPoint): ScreenPoint;
    /**
     * Transforms the specified screen point to a data point.
     * @param p The screen point.
     */
    inverseTransform(p: ScreenPoint): DataPoint;
}
//# sourceMappingURL=TransposableAnnotation.d.ts.map