import { Axis, AxisPosition, type CreateLinearAxisOptions, type DataPoint, type IRenderContext, LinearAxis, LineStyle, type OxyRect, type ScreenPoint, TickStyle, type TickValuesType } from '..';
export interface CreateAngleAxisOptions extends CreateLinearAxisOptions {
    /**
     * The start angle (degrees).
     */
    startAngle?: number;
    /**
     * The end angle (degrees).
     */
    endAngle?: number;
}
export declare const DefaultAngleAxisOptions: CreateAngleAxisOptions;
export declare const ExtendedDefaultAngleAxisOptions: {
    /**
     * The start angle (degrees).
     */
    startAngle?: number | undefined;
    /**
     * The end angle (degrees).
     */
    endAngle?: number | undefined;
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
    position?: AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: import('..').AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: import('..').AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an angular axis for polar plots.
 */
export declare class AngleAxis extends LinearAxis {
    /**
     * The start angle (degrees).
     */
    startAngle: number;
    /**
     * The end angle (degrees).
     */
    endAngle: number;
    /**
     * Initializes a new instance of the AngleAxis class.
     */
    constructor(opt?: CreateAngleAxisOptions);
    getElementName(): string;
    /**
     * Gets the coordinates used to draw ticks and tick labels (numbers or category names).
     */
    getTickValues(): TickValuesType;
    /**
     * Inverse transforms the specified screen point.
     * @throws Error if the method is called.
     */
    inverseTransformPoint(x: number, y: number, yaxis: Axis): DataPoint;
    /**
     * Determines whether the axis is used for X/Y values.
     * @returns false as it is not an XY axis.
     */
    isXyAxis(): boolean;
    /**
     * Renders the axis on the specified render context.
     */
    render(rc: IRenderContext, pass: number): Promise<void>;
    /**
     * Transforms the specified point to screen coordinates.
     * @throws Error if the method is called.
     */
    transformPoint(x: number, y: number, yaxis: Axis): ScreenPoint;
    /**
     * Updates the scale and offset properties of the transform from the specified boundary rectangle.
     * @internal
     */
    updateTransform(bounds: OxyRect): void;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=AngleAxis.d.ts.map