import { type AxisChangedEventArgs, AxisLayer, AxisPosition, type CreatePlotElementOptions, type DataPoint, type IRenderContext, LineStyle, type OxyColor, type OxyRect, type OxyThickness, PlotElement, type ScreenPoint, TickStyle } from '..';
export type AxisStringFormatterType = (x: any, ...args: any[]) => string;
export type AxisLabelFormatType = AxisStringFormatterType;
export type AxisTitleFormatterType = (title: string, unit: string) => string;
export interface TickValuesType {
    majorLabelValues: number[];
    majorTickValues: number[];
    minorTickValues: number[];
}
export interface CreateAxisOptions extends CreatePlotElementOptions {
    position?: AxisPosition;
    positionTier?: number;
    isAxisVisible?: boolean;
    layer?: AxisLayer;
    absoluteMaximum?: number;
    absoluteMinimum?: number;
    minimum?: number;
    maximum?: number;
    minorStep?: number;
    majorStep?: number;
    minimumMinorStep?: number;
    minimumMajorStep?: number;
    minimumMajorIntervalCount?: number;
    maximumMajorIntervalCount?: number;
    minimumPadding?: number;
    maximumPadding?: number;
    minimumRange?: number;
    maximumRange?: number;
    minimumDataMargin?: number;
    maximumDataMargin?: number;
    minimumMargin?: number;
    maximumMargin?: number;
    tickStyle?: TickStyle;
    ticklineColor?: OxyColor;
    minorTicklineColor?: OxyColor;
    axislineStyle?: LineStyle;
    axislineColor?: OxyColor;
    axislineThickness?: number;
    majorGridlineStyle?: LineStyle;
    majorGridlineColor?: OxyColor;
    majorGridlineThickness?: number;
    minorGridlineStyle?: LineStyle;
    minorGridlineColor?: OxyColor;
    minorGridlineThickness?: number;
    extraGridlines?: number[];
    extraGridlineStyle?: LineStyle;
    extraGridlineColor?: OxyColor;
    extraGridlineThickness?: number;
    minorTickSize?: number;
    majorTickSize?: number;
    startPosition?: number;
    stringFormatter?: AxisStringFormatterType;
    endPosition?: number;
    title?: string;
    titlePosition?: number;
    unit?: string;
    useSuperExponentialFormat?: boolean;
    titleFormatter?: AxisTitleFormatterType;
    titleClippingLength?: number;
    titleColor?: OxyColor;
    titleFontSize?: number;
    titleFontWeight?: number;
    clipTitle?: boolean;
    angle?: number;
    isZoomEnabled?: boolean;
    key?: string;
    isPanEnabled?: boolean;
    filterMinValue?: number;
    filterMaxValue?: number;
    filterFunction?: (value: number) => boolean;
    intervalLength?: number;
    axisDistance?: number;
    axisTitleDistance?: number;
    axisTickToLabelDistance?: number;
    dataMaximum?: number;
    dataMinimum?: number;
    labelFormatter?: AxisLabelFormatType;
    positionAtZeroCrossing?: boolean;
    cropGridlines?: boolean;
    positionTierMaxShift?: number;
    positionTierMinShift?: number;
    positionTierSize?: number;
}
export declare const DefaultAxisOptions: CreateAxisOptions;
export declare const ExtendedDefaultAxisOptions: {
    position?: AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Provides an abstract base class for axes.
 */
export declare abstract class Axis extends PlotElement {
    static readonly DefaultTitleFormatter: (title: string, unit: string) => string;
    /**
     * Exponent function.
     */
    protected static readonly Exponent: (x: number) => number;
    /**
     * Mantissa function.
     */
    protected static readonly Mantissa: (x: number) => number;
    /**
     * Rounds a value if the difference between the rounded value and the original value is less than 1e-6.
     */
    protected static readonly ThresholdRound: (x: number) => number;
    /**
     * The offset.
     */
    private _offset;
    /**
     * The scale.
     */
    private _scale;
    /**
     * Initializes a new instance of the Axis class.
     */
    protected constructor(opt?: CreateAxisOptions);
    /**
     * Occurs when the axis has been changed (by zooming, panning or resetting).
     * @deprecated May be removed in v4.0 (#111)
     */
    axisChanged?: (sender: any, event: AxisChangedEventArgs) => void;
    /**
     * Occurs when the transform changed (size or axis range was changed).
     * @deprecated May be removed in v4.0 (#111)
     */
    transformChanged?: (sender: any) => void;
    /**
     * Gets or sets the absolute maximum. This is only used for the UI control. It will not be possible to zoom/pan beyond this limit. The default value is Number.MAX_VALUE.
     */
    absoluteMaximum: number;
    /**
     * Gets or sets the absolute minimum. This is only used for the UI control. It will not be possible to zoom/pan beyond this limit. The default value is Number.MIN_VALUE.
     */
    absoluteMinimum: number;
    private _actualMajorStep;
    /**
     * Gets or sets the actual major step.
     */
    get actualMajorStep(): number;
    protected set actualMajorStep(value: number);
    /**
     * Gets or sets the minimum number of major intervals on the axis.
     * Non-integer values are accepted.
     */
    minimumMajorIntervalCount: number;
    /**
     * Gets or sets the minimum number of major intervals on the axis.
     * Non-integer values are accepted.
     * The maximum will be bounded according to the IntervalLength.
     * The MinimumMajorIntervalCount takes precedence over the MaximumMajorIntervalCount when determining the major step.
     */
    maximumMajorIntervalCount: number;
    private _actualMaximum;
    /**
     * Gets or sets the actual maximum value of the axis.
     * If ViewMaximum is not NaN, this value will be defined by ViewMaximum.
     * Otherwise, if Maximum is not NaN, this value will be defined by Maximum.
     * Otherwise, this value will be defined by the maximum (+padding) of the data.
     */
    get actualMaximum(): number;
    protected set actualMaximum(value: number);
    private _actualMinimum;
    /**
     * Gets or sets the actual minimum value of the axis.
     * If ViewMinimum is not NaN, this value will be defined by ViewMinimum.
     * Otherwise, if Minimum is not NaN, this value will be defined by Minimum.
     * Otherwise, this value will be defined by the minimum (+padding) of the data.
     */
    get actualMinimum(): number;
    protected set actualMinimum(value: number);
    private _clipMaximum;
    /**
     * Gets or sets the maximum displayed value on the axis, as determined by the ActualMaximum and MaximumDataMargin.
     * The value is refreshed by UpdateTransform(OxyRect), which is called before any plot elements are rendered.
     */
    get clipMaximum(): number;
    protected set clipMaximum(value: number);
    private _clipMinimum;
    /**
     * Gets or sets the minimum displayed value on the axis, as determined by the ActualMinimum and MinimumDataMargin.
     * The value is refreshed by UpdateTransform(OxyRect), which is called before any plot elements are rendered.
     */
    get clipMinimum(): number;
    protected set clipMinimum(value: number);
    private _actualMinorStep;
    /**
     * Gets or sets the actual minor step.
     */
    get actualMinorStep(): number;
    protected set actualMinorStep(value: number);
    private _actualStringFormatter?;
    /**
     * Gets or sets the actual string format being used.
     */
    get actualStringFormatter(): AxisStringFormatterType | undefined;
    protected set actualStringFormatter(value: AxisStringFormatterType | undefined);
    /**
     * Gets the actual title of the axis.
     * If the Unit property is set, the titleFormatter property is used to format the actual title.
     */
    get actualTitle(): string | undefined;
    /**
     * Gets or sets the orientation angle (degrees) for the axis labels. The default value is 0.
     */
    angle: number;
    /**
     * Gets or sets the distance from the end of the tick lines to the labels. The default value is 4.
     */
    axisTickToLabelDistance: number;
    /**
     * Gets or sets the minimum distance from the axis labels to the axis title. The default value is 4.
     */
    axisTitleDistance: number;
    /**
     * Gets or sets the distance between the plot area and the axis. The default value is 0.
     */
    axisDistance: number;
    /**
     * Gets or sets the color of the axis line. The default value is OxyColors.Black.
     */
    axislineColor: OxyColor;
    /**
     * Gets or sets the line style of the axis line. The default value is LineStyle.None.
     */
    axislineStyle: LineStyle;
    /**
     * Gets or sets the thickness of the axis line. The default value is 1.
     */
    axislineThickness: number;
    /**
     * Gets or sets a value indicating whether to clip the axis title. The default value is true.
     */
    clipTitle: boolean;
    /**
     * Gets or sets a value indicating whether to crop gridlines with perpendicular axes Start/EndPositions. The default value is false.
     */
    cropGridlines: boolean;
    private _dataMaximum;
    /**
     * Gets or sets the maximum value of the data displayed on this axis.
     */
    get dataMaximum(): number;
    protected set dataMaximum(value: number);
    private _dataMinimum;
    /**
     * Gets or sets the minimum value of the data displayed on this axis.
     */
    get dataMinimum(): number;
    protected set dataMinimum(value: number);
    /**
     * Gets or sets the end position of the axis on the plot area. The default value is 1.
     * The position is defined by a fraction in the range from 0 to 1, where 0 is at the bottom/left
     * and 1 is at the top/right.
     */
    endPosition: number;
    /**
     * Gets or sets the color of the extra gridlines. The default value is OxyColors.Black.
     */
    extraGridlineColor: OxyColor;
    /**
     * Gets or sets the line style of the extra gridlines. The default value is LineStyle.Solid.
     */
    extraGridlineStyle: LineStyle;
    /**
     * Gets or sets the thickness of the extra gridlines. The default value is 1.
     */
    extraGridlineThickness: number;
    /**
     * Gets or sets the values for the extra gridlines. The default value is null.
     */
    extraGridlines?: number[];
    /**
     * Gets or sets the filter function. The default value is null.
     */
    filterFunction?: (value: number) => boolean;
    /**
     * Gets or sets the maximum value that can be shown using this axis. Values greater or equal to this value will not be shown. The default value is Number.MAX_VALUE.
     */
    filterMaxValue: number;
    /**
     * Gets or sets the minimum value that can be shown using this axis. Values smaller or equal to this value will not be shown. The default value is Number.MIN_VALUE.
     */
    filterMinValue: number;
    /**
     * Gets or sets the maximum length (screen space) of the intervals. The available length of the axis will be divided by this length to get the approximate number of major intervals on the axis. The default value is 60.
     */
    intervalLength: number;
    /**
     * Gets or sets a value indicating whether this axis is visible. The default value is true.
     */
    isAxisVisible: boolean;
    /**
     * Gets or sets a value indicating whether panning is enabled. The default value is true.
     */
    isPanEnabled: boolean;
    /**
     * Gets a value indicating whether this axis is reversed. It is reversed if StartPosition > EndPosition.
     */
    get isReversed(): boolean;
    /**
     * Gets or sets a value indicating whether zooming is enabled. The default value is true.
     */
    isZoomEnabled: boolean;
    /**
     * Gets or sets the key of the axis. This can be used to specify an axis if you have defined multiple axes in a plot. The default value is null.
     */
    key?: string;
    /**
     * Gets or sets the formatting function for the labels. The default value is null.
     * This function can be used instead of overriding the FormatValue method.
     */
    labelFormatter?: AxisLabelFormatType;
    /**
     * Gets or sets the layer of the axis. The default value is AxisLayer.BelowSeries.
     */
    layer: AxisLayer;
    /**
     * Gets or sets the color of the major gridlines. The default value is #40000000.
     */
    majorGridlineColor: OxyColor;
    /**
     * Gets or sets the line style of the major gridlines. The default value is LineStyle.None.
     */
    majorGridlineStyle: LineStyle;
    /**
     * Gets or sets the thickness of the major gridlines. The default value is 1.
     */
    majorGridlineThickness: number;
    /**
     * Gets or sets the interval between major ticks. The default value is NaN.
     */
    majorStep: number;
    /**
     * Gets or sets the size of the major ticks. The default value is 7.
     */
    majorTickSize: number;
    /**
     * Gets or sets the maximum value of the axis. The default value is NaN.
     */
    maximum: number;
    /**
     * Gets or sets the 'padding' fraction of the maximum value. The default value is 0.01.
     * A value of 0.01 gives 1% more space on the maximum end of the axis. This property is not used if the Maximum property is set.
     */
    maximumPadding: number;
    /**
     * Gets or sets the screen-space data margin at the maximum. The default value is 0.
     * The number of device independent units to included between the ClipMaximum and ActualMaximum.
     */
    maximumDataMargin: number;
    /**
     * Gets or sets the screen-space margin at the maximum. The default value is 0.
     * The number of device independent units to be left empty between the axis and the EndPosition.
     */
    maximumMargin: number;
    /**
     * Gets or sets the maximum range of the axis. Setting this property ensures that ActualMaximum-ActualMinimum < MaximumRange. The default value is Number.POSITIVE_INFINITY.
     */
    maximumRange: number;
    /**
     * Gets or sets the minimum value of the axis. The default value is NaN.
     */
    minimum: number;
    /**
     * Gets or sets the minimum value for the interval between major ticks. The default value is 0.
     */
    minimumMajorStep: number;
    /**
     * Gets or sets the minimum value for the interval between minor ticks. The default value is 0.
     */
    minimumMinorStep: number;
    /**
     * Gets or sets the 'padding' fraction of the minimum value. The default value is 0.01.
     * A value of 0.01 gives 1% more space on the minimum end of the axis. This property is not used if the Minimum property is set.
     */
    minimumPadding: number;
    /**
     * Gets or sets the screen-space data margin at the minimum. The default value is 0.
     * The number of device independent units to included between the ClipMinimum and ActualMinimum.
     */
    minimumDataMargin: number;
    /**
     * Gets or sets the screen-space margin at the minimum. The default value is 0.
     * The number of device independent units to be left empty between the axis the StartPosition.
     */
    minimumMargin: number;
    /**
     * Gets or sets the minimum range of the axis. Setting this property ensures that ActualMaximum-ActualMinimum > MinimumRange. The default value is 0.
     */
    minimumRange: number;
    /**
     * Gets or sets the color of the minor gridlines. The default value is #20000000.
     */
    minorGridlineColor: OxyColor;
    /**
     * Gets or sets the line style of the minor gridlines. The default value is LineStyle.None.
     */
    minorGridlineStyle: LineStyle;
    /**
     * Gets or sets the thickness of the minor gridlines. The default value is 1.
     */
    minorGridlineThickness: number;
    /**
     * Gets or sets the interval between minor ticks. The default value is NaN.
     */
    minorStep: number;
    /**
     * Gets or sets the color of the minor ticks. The default value is OxyColors.Automatic.
     * If the value is OxyColors.Automatic, the value of
     * Axis.TicklineColor will be used.
     */
    minorTicklineColor: OxyColor;
    /**
     * Gets or sets the size of the minor ticks. The default value is 4.
     */
    minorTickSize: number;
    /**
     * Gets the offset. This is used to transform between data and screen coordinates.
     */
    get offset(): number;
    /**
     * Gets or sets the position of the axis. The default value is AxisPosition.Left.
     */
    position: AxisPosition;
    /**
     * Gets or sets a value indicating whether the axis should be positioned at the zero-crossing of the related axis. The default value is false.
     */
    positionAtZeroCrossing: boolean;
    /**
     * Gets or sets the position tier which defines in which tier the axis is displayed. The default value is 0.
     * The bigger the value the further afar is the axis from the graph.
     */
    positionTier: number;
    /**
     * Gets the scaling factor of the axis. This is used to transform between data and screen coordinates.
     */
    get scale(): number;
    private _screenMax;
    /**
     * Gets or sets the screen coordinate of the maximum end of the axis.
     */
    get screenMax(): ScreenPoint;
    protected set screenMax(value: ScreenPoint);
    /**
     * Gets or sets the screen coordinate of the minimum end of the axis.
     */
    private _screenMin;
    get screenMin(): ScreenPoint;
    protected set screenMin(value: ScreenPoint);
    /**
     * Gets or sets the start position of the axis on the plot area. The default value is 0.
     * The position is defined by a fraction in the range from 0 to 1, where 0 is at the bottom/left
     * and 1 is at the top/right.
     */
    startPosition: number;
    /**
     * Gets or sets the string format used for formatting the axis values. The default value is null.
     */
    stringFormatter?: AxisStringFormatterType;
    /**
     * Gets or sets the tick style for major and minor ticks. The default value is TickStyle.Outside.
     */
    tickStyle: TickStyle;
    /**
     * Gets or sets the color of the major and minor ticks. The default value is OxyColors.Black.
     */
    ticklineColor: OxyColor;
    /**
     * Gets or sets the title of the axis. The default value is null.
     */
    title?: string;
    /**
     * Gets or sets the length of the title clipping rectangle (fraction of the available length of the axis). The default value is 0.9.
     */
    titleClippingLength: number;
    /**
     * Gets or sets the color of the title. The default value is OxyColors.Automatic.
     * If the value is null, the PlotModel.TextColor will be used.
     */
    titleColor: OxyColor;
    /**
     * Gets or sets the title font. The default value is null.
     */
    titleFont?: string;
    /**
     * Gets or sets the size of the title font. The default value is NaN.
     */
    titleFontSize: number;
    /**
     * Gets or sets the weight of the title font. The default value is FontWeights.Normal.
     */
    titleFontWeight: number;
    /**
     * Gets or sets the formatter used for formatting the title and unit when Unit is defined.
     * The default value is "{0} [{1}]", where {0} refers to the Title and {1} refers to the Unit.
     * If Unit is null, the actual title is defined by Title only.
     */
    titleFormatter: AxisTitleFormatterType;
    /**
     * Gets or sets the position of the title. The default value is 0.5.
     * The position is defined by a fraction in the range 0 to 1.
     */
    titlePosition: number;
    /**
     * Gets or sets the unit of the axis. The default value is null.
     * The titleFormatter is used to format the title including this unit.
     */
    unit?: string;
    /**
     * Gets or sets a value indicating whether to use superscript exponential format. The default value is false.
     * This format will convert 1.5E+03 to 1.5·10^{3} and render the superscript properly.
     * If StringFormatter is null, 1.0E+03 will be converted to 10^{3}, otherwise it will use the formatter for the mantissa.
     */
    useSuperExponentialFormat: boolean;
    private _desiredMargin;
    /**
     * Gets or sets the desired margins such that the axis text ticks will not be clipped.
     * The actual margins may be smaller or larger than the desired margins if they are set manually.
     */
    get desiredMargin(): OxyThickness;
    protected set desiredMargin(value: OxyThickness);
    /**
     * Gets or sets the position tier max shift.
     * @internal
     */
    positionTierMaxShift: number;
    /**
     * Gets or sets the position tier min shift.
     * @internal
     */
    positionTierMinShift: number;
    /**
     * Gets or sets the size of the position tier.
     * @internal
     */
    positionTierSize: number;
    /**
     * Gets the actual color of the title.
     * @internal
     */
    get actualTitleColor(): OxyColor;
    /**
     * Gets the actual title font.
     * @internal
     */
    get actualTitleFont(): string;
    /**
     * Gets the actual size of the title font.
     * @internal
     */
    get actualTitleFontSize(): number;
    /**
     * Gets the actual title font weight.
     * @internal
     */
    get actualTitleFontWeight(): number;
    /**
     * Gets or sets the current view's maximum. This value is used when the user zooms or pans.
     */
    protected viewMaximum: number;
    /**
     * Gets or sets the current view's minimum. This value is used when the user zooms or pans.
     */
    protected viewMinimum: number;
    /**
     * Converts the specified value to a number.
     * @param item
     * @protected
     */
    itemToDouble(item: any): number;
    /**
     * Transforms the specified point from screen space to data space.
     * @param p The point.
     * @param xaxis The x-axis.
     * @param yaxis The y-axis.
     * @returns The data point.
     */
    static inverseTransform(p: ScreenPoint, xaxis: Axis, yaxis: Axis): DataPoint;
    /**
     * Formats the value to be used on the axis.
     * @param x The value.
     * @returns The formatted value.
     */
    formatValue(x: number): string;
    /**
     * Gets the coordinates used to draw ticks and tick labels (numbers or category names).
     */
    getTickValues(): TickValuesType;
    /**
     * Gets the value from an axis coordinate, converts from a coordinate number value to the actual data type.
     * @param x The coordinate.
     * @returns The converted value.
     */
    getValue(x: number): any;
    /**
     * Inverse transform the specified .
     * @param x The x or screen coordinate.
     * @param y The y coordinate.
     * @param yaxis The y-axis.
     * @returns The data point.
     */
    inverseTransformPoint(x: number, y: number, yaxis: Axis): DataPoint;
    /**
     * Inverse transforms the specified screen coordinate. This method can only be used with non-polar coordinate systems.
     * @param sx The screen coordinate.
     * @returns The value.
     */
    inverseTransform(sx: number): number;
    /**
     * Determines whether the axis is horizontal.
     * @returns true if the axis is horizontal; otherwise, false.
     */
    isHorizontal(): boolean;
    /**
     * Determines whether the specified value is valid.
     * @param value The value.
     * @returns true if the specified value is valid; otherwise, false.
     */
    isValidValue(value: number): boolean;
    /**
     * Determines whether the axis is vertical.
     * @returns true if the axis is vertical; otherwise, false.
     */
    isVertical(): boolean;
    /**
     * Determines whether the axis is used for X/Y values.
     * @returns true if it is an XY axis; otherwise, false.
     */
    abstract isXyAxis(): boolean;
    /**
     * Determines whether the axis is logarithmic.
     * @returns true if it is a logarithmic axis; otherwise, false.
     */
    isLogarithmic(): boolean;
    /**
     * Measures the size of the axis and updates DesiredMargin accordingly. This takes into account the axis title as well as tick labels
     * potentially exceeding the axis range.
     * @param rc The render context.
     */
    measure(rc: IRenderContext): void;
    pan(ppt_or_delta: ScreenPoint | number, cpt?: ScreenPoint): void;
    /**
     * Pans the specified axis.
     * @param ppt The previous point (screen coordinates).
     * @param cpt The current point (screen coordinates).
     */
    private pan1;
    /**
     * Pans the specified axis.
     * @param delta The delta.
     */
    private pan2;
    /**
     * Renders the axis on the specified render context.
     * @param rc The render context.
     * @param pass The pass.
     */
    render(rc: IRenderContext, pass: number): Promise<void>;
    /**
     * Resets the user's modification (zooming/panning) to minimum and maximum of this axis.
     */
    reset(): void;
    /**
     * Returns a string that represents this instance.
     * @returns A string that represents this instance.
     */
    toString(): string;
    /**
     * Transforms the specified point to screen coordinates.
     * @param x The x value (for the current axis).
     * @param y The y value.
     * @param yaxis The y-axis.
     * @returns The transformed point.
     */
    transformPoint(x: number, y: number, yaxis: Axis): ScreenPoint;
    /**
     * Transforms the specified coordinate to screen coordinates. This method can only be used with non-polar coordinate systems.
     * @param x The value.
     * @returns The transformed value (screen coordinate).
     */
    transform(x: number): number;
    /**
     * Zoom to the specified scale.
     * @param newScale The new scale.
     */
    zoomScale(newScale: number): void;
    /**
     * Zooms the axis to the range [x0,x1].
     * @param x0 The new minimum.
     * @param x1 The new maximum.
     */
    zoom(x0: number, x1: number): void;
    /**
     * Zooms the axis at the specified coordinate.
     * @param factor The zoom factor.
     * @param x The coordinate to zoom at.
     */
    zoomAt(factor: number, x: number): void;
    /**
     * Zooms the axis with the specified zoom factor at the center of the axis.
     * @param factor The zoom factor.
     */
    zoomAtCenter(factor: number): void;
    /**
     * Modifies the data range of the axis [DataMinimum,DataMaximum] to includes the specified value.
     * @param value The value.
     */
    include(value: number): void;
    /**
     * Resets the DataMaximum and DataMinimum values.
     * @internal
     */
    resetDataMaxMin(): void;
    /**
     * Updates the ActualMaximum and ActualMinimum values.
     * @internal
     */
    updateActualMaxMin(): void;
    /**
     * Updates the actual minor and major step intervals.
     * @param plotArea The plot area rectangle.
     * @internal
     */
    updateIntervals(plotArea: OxyRect): void;
    /**
     * Updates the scale and offset properties of the transform from the specified boundary rectangle.
     * @param bounds The bounds.
     * @internal
     */
    updateTransform(bounds: OxyRect): void;
    /**
     * Invoked when ActualMinimum, ActualMaximum, ClipMinimum, and ClipMaximum are changed.
     */
    protected actualMaximumAndMinimumChangedOverride(): void;
    /**
     * Gets the default formatter.
     * @returns A formatter.
     * @remarks This formatter is used if the StringFormat is not set.
     */
    protected getDefaultStringFormatter(): AxisStringFormatterType | undefined;
    /**
     * Applies a transformation after the inverse transform of the value.
     * @param x The value to transform.
     * @returns The transformed value.
     * @remarks If this method is overridden, the inverseTransform method must also be overridden.
     * See LogarithmicAxis for examples on how to implement this.
     */
    protected postInverseTransform(x: number): number;
    /**
     * Applies a transformation before the transform the value.
     * @param x The value to transform.
     * @returns The transformed value.
     * @remarks If this method is overridden, the transform method must also be overridden.
     * See LogarithmicAxis for examples on how to implement this.
     */
    protected preTransform(x: number): number;
    /**
     * Calculates the minor interval.
     * @param majorInterval The major interval.
     * @returns The minor interval.
     */
    protected calculateMinorInterval(majorInterval: number): number;
    /**
     * Creates tick values at the specified interval.
     * @param from The start value.
     * @param to The end value.
     * @param step The interval.
     * @param maxTicks The maximum number of ticks (optional). The default value is 1000.
     * @returns A sequence of values.
     */
    protected createTickValues(from: number, to: number, step: number, maxTicks?: number): number[];
    /**
     * Coerces the actual maximum and minimum values.
     */
    protected coerceActualMaxMin(): void;
    /**
     * Formats the value to be used on the axis.
     * @param x The value to format.
     * @returns The formatted value.
     */
    protected formatValueOverride(x: number): string;
    /**
     * Calculates the actual maximum value of the axis, including the MaximumPadding.
     * @returns The new actual maximum value of the axis.
     * @remarks Must be called before CalculateActualMinimum
     */
    protected calculateActualMaximum(): number;
    /**
     * Calculates the actual minimum value of the axis, including the MinimumPadding.
     * @returns The new actual minimum value of the axis.
     * @remarks Must be called after CalculateActualMaximum
     */
    protected calculateActualMinimum(): number;
    /**
     * Sets the transform.
     * @param newScale The new scale.
     * @param newOffset The new offset.
     */
    protected setTransform(newScale: number, newOffset: number): void;
    /**
     * Returns the actual interval to use to determine which values are displayed in the axis.
     * @param availableSize The available size.
     * @param maxIntervalSize The maximum interval size.
     * @param range The range.
     * @param minIntervalCount The minimum number of intervals.
     * @param maxIntervalCount The maximum number of intervals, once the minimum number of intervals is satisfied.
     * @returns Actual interval to use to determine which values are displayed in the axis.
     */
    protected calculateActualInterval(availableSize: number, maxIntervalSize: number, minIntervalCount: number, maxIntervalCount: number, range?: number): number;
    /**
     * Raises the AxisChanged event.
     * @param args The AxisChangedEventArgs instance containing the event data.
     */
    protected onAxisChanged(args: AxisChangedEventArgs): void;
    /**
     * Raises the TransformChanged event.
     */
    protected onTransformChanged(): void;
    protected getJsonIgnoreProperties(): string[];
}
//# sourceMappingURL=Axis.d.ts.map