/**
 * Static utility methods for the Axis classes.
 */
export declare class AxisUtilities {
    /**
     * Calculates the minor interval.
     * @param majorInterval The major interval.
     * @returns The minor interval.
     */
    static calculateMinorInterval(majorInterval: number): number;
    /**
     * Calculates the minor interval (alternative algorithm).
     * @param majorInterval The major interval.
     * @returns The minor interval.
     */
    static calculateMinorInterval2(majorInterval: number): number;
    /**
     * Creates tick values at the specified interval.
     * @param from The start value.
     * @param to The end value.
     * @param step The interval.
     * @param maxTicks The maximum number of ticks (optional). The default value is 1000.
     * @returns A sequence of values.
     */
    static createTickValues(from: number, to: number, step: number, maxTicks?: number): number[];
    /**
     * Analyses two lists of major and minor ticks and creates a new containing the subset of the minor ticks which are not too close to any of the major ticks.
     * @param majorTicks The major ticks. Must be monotonically ascending or descending.
     * @param minorTicks The minor ticks. Must be monotonically ascending or descending (same direction as major ticks).
     * @returns A new list containing a subset of the original minor ticks such that there are no minor ticks too close to a major tick.
     */
    static filterRedundantMinorTicks(majorTicks: number[], minorTicks: number[]): number[];
}
//# sourceMappingURL=AxisUtilities.d.ts.map