import { AxisPosition, type CreateAxisOptions, LinearAxis, type PlotModelSerializeOptions, TickStyle, type TickValuesType } from '..';
export interface CreateCategoryAxisOptions extends CreateAxisOptions {
    gapWidth?: number;
    isTickCentered?: boolean;
    itemsSource?: any[];
    labelField?: string;
    labels?: string[];
}
export declare const DefaultCategoryAxisOptions: CreateCategoryAxisOptions;
export declare const ExtendedDefaultCategoryAxisOptions: {
    gapWidth?: number | undefined;
    isTickCentered?: boolean | undefined;
    itemsSource?: any[] | undefined;
    labelField?: string | undefined;
    labels?: string[] | undefined;
    position?: AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: import('..').LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: import('..').LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: import('..').LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: import('..').LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: import('..').AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: import('..').AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
};
/**
 * Represents a category axis.
 * The category axis is using the index of the label collection items as coordinates.
 * If you have 5 categories in the Labels collection, the categories will be placed at coordinates 0 to 4.
 * The range of the axis will be from -0.5 to 4.5 (excluding padding).
 */
export declare class CategoryAxis extends LinearAxis {
    /**
     * The auto-generated labels.
     */
    private _autoGeneratedLabels;
    /**
     * The labels from the ItemsSource.
     */
    private _itemsSourceLabels;
    /**
     * Initializes a new instance of the CategoryAxis class.
     */
    constructor(opt?: CreateCategoryAxisOptions);
    getElementName(): string;
    /**
     * Gets the actual category labels.
     */
    get actualLabels(): string[];
    /**
     * Gets or sets the gap width.
     * The default value is 1.0 (100%). The gap width is given as a fraction of the total width/height of the items in a category.
     */
    gapWidth: number;
    /**
     * Gets or sets a value indicating whether the ticks are centered. If this is false, ticks will be drawn between each category. If this is true, ticks will be drawn in the middle of each category.
     */
    isTickCentered: boolean;
    /**
     * Gets or sets the items source (used to update the Labels collection).
     */
    itemsSource?: any[];
    /**
     * Gets or sets the data field for the labels.
     */
    labelField?: string;
    private _labels;
    /**
     * Gets the list of category labels.
     */
    get labels(): string[];
    /**
     * Gets the actual category labels.
     */
    getTickValues(): TickValuesType;
    /**
     * Gets the value from the axis.
     */
    getValue(x: number): any;
    /**
     * Updates the actual maximum and minimum values of the axis.
     */
    updateActualMaxMin(): void;
    /**
     * Updates the category labels.
     */
    updateLabels(numberOfCategories: number): void;
    /**
     * Formats the specified value to a string.
     */
    protected formatValueOverride(x: number): string;
    protected getElementDefaultValues(): any;
    toJSON(opt?: PlotModelSerializeOptions): any;
}
//# sourceMappingURL=CategoryAxis.d.ts.map