import { AxisPosition, type AxisStringFormatterType, type CreateLinearAxisOptions, type DataPoint, DateTimeIntervalType, LinearAxis, type OxyRect } from '..';
import { DayOfWeek } from '../types';
export interface CreateDateTimeAxisOptions extends CreateLinearAxisOptions {
    firstDayOfWeek?: DayOfWeek;
    intervalType?: DateTimeIntervalType;
    minorIntervalType?: DateTimeIntervalType;
    timeZone?: string;
}
export declare const DefaultDateTimeAxisOptions: CreateDateTimeAxisOptions;
export declare const ExtendedDefaultDateTimeAxisOptions: {
    firstDayOfWeek?: DayOfWeek | undefined;
    intervalType?: DateTimeIntervalType | undefined;
    minorIntervalType?: DateTimeIntervalType | undefined;
    timeZone?: string | undefined;
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
    position?: AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: import('..').TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: import('..').LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: import('..').LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: import('..').LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: import('..').LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/** Represents an axis presenting DateTime values. */
export declare class DateTimeAxis extends LinearAxis {
    /**
     * The time origin.
     * Note: The time origin in c# is 1899-12-31
     */
    private static readonly TimeOrigin;
    /**
     * The time origin difference in days to the c# time origin.
     */
    static readonly TimeOriginDiffDaysToCSharp = 366;
    /** The maximum day value */
    private static MaxDayValue;
    /** The minimum day value */
    private static MinDayValue;
    /** The actual interval type. */
    private _actualIntervalType;
    /** The actual minor interval type. */
    private _actualMinorIntervalType;
    /** Initializes a new instance of the DateTimeAxis class. */
    constructor(opt?: CreateDateTimeAxisOptions);
    getElementName(): string;
    private readonly _dateService;
    /** Gets or sets FirstDayOfWeek. */
    firstDayOfWeek: DayOfWeek;
    /** Gets or sets IntervalType. */
    intervalType: DateTimeIntervalType;
    /** Gets or sets MinorIntervalType. */
    minorIntervalType: DateTimeIntervalType;
    /** Gets or sets the time zone (used when formatting date/time values). */
    timeZone?: string;
    /** Creates a data point. */
    static createDataPoint(x: Date, y: number): DataPoint;
    /** Converts a numeric representation of the date (number of days after the time origin) to a DateTime structure. */
    static toDateTime(value: number): Date;
    /**
     * Converts a numeric representation of the date (number of days after the time origin of .net version) to a DateTime structure.
     */
    static fromDotNetValue(value: number): Date;
    /** Converts a DateTime to days after the time origin. */
    static toDouble(value: Date): number;
    /** Converts a DateTime to days after the time origin. */
    itemToDouble(item: any): number;
    /** Gets the tick values. */
    getTickValues(): {
        majorLabelValues: number[];
        majorTickValues: number[];
        minorTickValues: number[];
    };
    /** Gets the value from an axis coordinate, converts from double to the correct data type if necessary. */
    getValue(x: number): Date;
    updateIntervals(plotArea: OxyRect): void;
    protected getDefaultStringFormatter(): AxisStringFormatterType;
    protected formatValueOverride(x: number): string;
    /**
     * Calculates the actual interval for a DateTimeAxis.
     * @param availableSize The available size for the axis.
     * @param maxIntervalSize The maximum size of an interval.
     * @param minIntervalCount The minimum number of intervals.
     * @param maxIntervalCount The maximum number of intervals.
     * @returns The actual interval size.
     */
    protected calculateActualInterval(availableSize: number, maxIntervalSize: number, minIntervalCount: number, maxIntervalCount: number, range?: number): number;
    /**
     * Creates the date tick values.
     * @param min The minimum value of the axis.
     * @param max The maximum value of the axis.
     * @param step The step size for generating ticks.
     * @param intervalType The type of interval for generating ticks.
     * @returns A list of date tick values.
     */
    private createDateTickValues;
    /**
     * Creates DateTime tick values.
     * @param min The minimum value of the axis.
     * @param max The maximum value of the axis.
     * @param interval The interval value for tick generation.
     * @param intervalType The type of interval used for tick generation.
     * @returns A list of DateTime tick values.
     */
    private createDateTimeTickValues;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=DateTimeAxis.d.ts.map