import { Axis, type CreateAxisOptions } from '..';
export interface CreateLinearAxisOptions extends CreateAxisOptions {
    fractionUnit?: number;
    fractionUnitSymbol?: string;
    formatAsFractions?: boolean;
}
export declare const DefaultLinearAxisOptions: CreateLinearAxisOptions;
export declare const ExtendedDefaultLinearAxisOptions: {
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
    position?: import('..').AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: import('..').TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: import('..').LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: import('..').LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: import('..').LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: import('..').LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: import('..').AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: import('..').AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an axis with linear scale.
 */
export declare class LinearAxis extends Axis {
    /**
     * Initializes a new instance of the LinearAxis class.
     */
    constructor(opt?: CreateLinearAxisOptions);
    getElementName(): string;
    /**
     * Gets or sets a value indicating whether to format numbers as fractions.
     */
    formatAsFractions: boolean;
    /**
     * Gets or sets the fraction unit. Remember to set formatAsFractions to true.
     */
    fractionUnit: number;
    /**
     * Gets or sets the fraction unit symbol. Use fractionUnit = Math.PI and fractionUnitSymbol = "π" if you want the axis to show "π/2,π,3π/2,2π" etc. Use fractionUnit = 1 and fractionUnitSymbol = "L" if you want the axis to show "0,L/2,L" etc. Remember to set formatAsFractions to true.
     */
    fractionUnitSymbol?: string;
    /**
     * Determines whether the axis is used for X/Y values.
     * @returns true if it is an XY axis; otherwise, false.
     */
    isXyAxis(): boolean;
    /**
     * Determines whether the axis is logarithmic.
     * @returns true if it is a logarithmic axis; otherwise, false.
     */
    isLogarithmic(): boolean;
    /**
     * Formats the value to be used on the axis.
     * @param x The value to format.
     * @returns The formatted value.
     */
    protected formatValueOverride(x: number): string;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=LinearAxis.d.ts.map