import { Axis, AxisPosition, type CreateLinearAxisOptions, type DataPoint, type IRenderContext, LinearAxis, LineStyle, type OxyRect, type ScreenPoint } from '..';
export interface CreateMagnitudeAxisOptions extends CreateLinearAxisOptions {
    /**
     * The midpoint (screen coordinates) of the plot area. This is used by polar coordinate systems.
     */
    midPoint?: ScreenPoint;
}
export declare const DefaultMagnitudeAxisOptions: CreateMagnitudeAxisOptions;
export declare const ExtendedDefaultMagnitudeAxisOptions: {
    /**
     * The midpoint (screen coordinates) of the plot area. This is used by polar coordinate systems.
     */
    midPoint?: ScreenPoint | undefined;
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
    position?: AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: import('..').TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: import('..').AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: import('..').AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents a magnitude axis for polar plots.
 */
export declare class MagnitudeAxis extends LinearAxis {
    /**
     * The midpoint (screen coordinates) of the plot area. This is used by polar coordinate systems.
     * @internal
     */
    midPoint: ScreenPoint;
    /**
     * Initializes a new instance of the MagnitudeAxis class.
     */
    constructor(opt?: CreateMagnitudeAxisOptions);
    getElementName(): string;
    /**
     * Inverse transform the specified screen point.
     * @param x The x coordinate.
     * @param y The y coordinate.
     * @param yaxis The y-axis.
     * @returns The data point.
     * @throws Error if polar angle axis not defined.
     */
    inverseTransformPoint(x: number, y: number, yaxis: Axis): DataPoint;
    /**
     * Determines whether the axis is used for X/Y values.
     * @returns false as it is not an XY axis.
     */
    isXyAxis(): boolean;
    /**
     * Renders the axis on the specified render context.
     * @param rc The render context.
     * @param pass The rendering pass.
     */
    render(rc: IRenderContext, pass: number): Promise<void>;
    /**
     * Transforms the specified point to screen coordinates.
     * @param x The x value (for the current axis).
     * @param y The y value.
     * @param yaxis The y-axis.
     * @returns The transformed point.
     * @throws Error if polar angle axis not defined.
     */
    transformPoint(x: number, y: number, yaxis: Axis): ScreenPoint;
    /**
     * Updates the scale and offset properties of the transform from the specified boundary rectangle.
     * @param bounds The bounds.
     */
    updateTransform(bounds: OxyRect): void;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=MagnitudeAxis.d.ts.map