import { AxisPosition, type CreateLinearAxisOptions, type IColorAxis, type IRenderContext, LinearAxis, type OxyColor } from '..';
export interface CreateRangeColorAxisOptions extends CreateLinearAxisOptions {
    /** The color of values above the maximum value. */
    highColor?: OxyColor;
    /** The color of values below the minimum value. */
    lowColor?: OxyColor;
    /** The invalid category color. */
    invalidNumberColor?: OxyColor;
}
export declare const DefaultRangeColorAxisOptions: CreateRangeColorAxisOptions;
export declare const ExtendedDefaultRangeColorAxisOptions: {
    /** The color of values above the maximum value. */
    highColor?: string | undefined;
    /** The color of values below the minimum value. */
    lowColor?: string | undefined;
    /** The invalid category color. */
    invalidNumberColor?: string | undefined;
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
    position?: AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: import('..').TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: import('..').LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: import('..').LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: import('..').LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: import('..').LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: import('..').AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: import('..').AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/** Represents a color axis that contains colors for specified ranges. */
export declare class RangeColorAxis extends LinearAxis implements IColorAxis {
    /** The ranges */
    private readonly _ranges;
    get ranges(): ColorRange[];
    /** The invalid category color. */
    invalidNumberColor: OxyColor;
    /** The color of values above the maximum value. */
    highColor: OxyColor;
    /** The color of values below the minimum value. */
    lowColor: OxyColor;
    constructor(opt?: CreateRangeColorAxisOptions);
    getElementName(): string;
    /** Adds a range. */
    addRange(lowerBound: number, upperBound: number, color: OxyColor): void;
    /** Clears the ranges. */
    clearRanges(): void;
    /** Gets the palette index of the specified value. */
    getPaletteIndex(value: number): number;
    /** Gets the color. */
    getColor(paletteIndex: number): OxyColor;
    render(rc: IRenderContext, pass: number): Promise<void>;
    protected getElementDefaultValues(): any;
}
/** Defines a range. */
interface ColorRange {
    /** The color. */
    color: OxyColor;
    /** The lower bound. */
    lowerBound: number;
    /** The upper bound. */
    upperBound: number;
}
export {};
//# sourceMappingURL=RangeColorAxis.d.ts.map