import { Axis, AxisPosition, type IRenderContext, OxyPen, PlotModel, TickStyle } from '../..';
/**
 * Provides an abstract base class for axis renderers.
 */
export declare abstract class AxisRendererBase<T extends Axis = Axis> {
    /**
     * The plot.
     */
    private readonly _plot;
    /**
     * The render context.
     */
    private readonly rc;
    /**
     * The minor tick values
     */
    protected minorTickValues: number[];
    /**
     * Initializes a new instance of the AxisRendererBase class.
     * @param rc The render context.
     * @param plot The plot.
     */
    protected constructor(rc: IRenderContext, plot: PlotModel);
    /**
     * Gets the plot.
     */
    protected get plot(): PlotModel;
    /**
     * Gets the render context.
     */
    protected get renderContext(): IRenderContext;
    /**
     * Gets or sets the axis lines pen.
     */
    protected axislinePen?: OxyPen;
    /**
     * Gets or sets the extra grid lines pen.
     */
    protected extraPen?: OxyPen;
    /**
     * Gets or sets the major label values.
     */
    protected majorLabelValues: number[];
    /**
     * Gets or sets the major grid lines pen.
     */
    protected majorPen?: OxyPen;
    /**
     * Gets or sets the major tick pen.
     */
    protected majorTickPen?: OxyPen;
    /**
     * Gets or sets the major tick values.
     */
    protected majorTickValues: number[];
    /**
     * Gets or sets the minor grid lines pen.
     */
    protected minorPen?: OxyPen;
    /**
     * Gets or sets the minor tick pen.
     */
    protected minorTickPen?: OxyPen;
    /**
     * Gets or sets the zero grid line pen.
     */
    protected zeroPen?: OxyPen;
    /**
     * Renders the specified axis.
     * @param axis The axis.
     * @param pass The pass.
     */
    render(axis: T, pass: number): Promise<void>;
    /**
     * Creates the pens.
     * @param axis The axis.
     */
    protected createPens(axis: T): void;
    /**
     * Gets the tick positions.
     * @param axis The axis.
     * @param tickStyle The tick style.
     * @param tickSize The tick size.
     * @param position The position.
     * @param pos
     */
    protected getTickPositions(axis: T, tickStyle: TickStyle, tickSize: number, position: AxisPosition): [number, number];
    /**
     * Determines whether the specified value is within the specified range.
     * @param d The value to check.
     * @param min The minimum value of the range.
     * @param max The maximum value of the range.
     * @returns true if the specified value is within the range; otherwise, false.
     */
    protected isWithin(d: number, min: number, max: number): boolean;
}
//# sourceMappingURL=AxisRendererBase.d.ts.map