import { Axis, HorizontalAndVerticalAxisRenderer, type IColorAxis, type IRenderContext, type OxyColor, PlotModel } from '../..';
/**
 * Provides functionality to render color axes.
 */
export declare abstract class ColorAxisRenderer<T extends Axis & IColorAxis> extends HorizontalAndVerticalAxisRenderer {
    /**
     * Position of the left edge of the color block.
     */
    protected left: number;
    /**
     * Position of the top edge of the color block.
     */
    protected top: number;
    /**
     * 'Size' of the color block; this is the width for vertical axes, or the height for horizontal axes.
     */
    protected size: number;
    /**
     * Screen position of the minimum value of the axis.
     */
    protected minScreenPosition: number;
    /**
     * Screen position of the maximum value of the axis.
     */
    protected maxScreenPosition: number;
    /**
     * Initializes a new instance of the ColorAxisRenderer class.
     */
    protected constructor(rc: IRenderContext, plot: PlotModel);
    /**
     * Initializes fields containing information about position and size of the color axis on screen.
     */
    protected initPosition(axis: T): void;
    render(axis: T, pass: number): Promise<void>;
    /**
     * Renders the color block.
     */
    protected abstract renderColorBlock(axis: T): Promise<void>;
    /**
     * Draws a single colored rectangle at the provided screen position.
     */
    protected drawColorRect(axis: T, yLow: number, yHigh: number, color: OxyColor): Promise<void>;
}
//# sourceMappingURL=ColorAxisRenderer.d.ts.map