import { AxisRendererBase, type IRenderContext, MagnitudeAxis, PlotModel } from '../..';
/**
 * Provides functionality to render MagnitudeAxis.
 */
export declare class MagnitudeAxisRenderer extends AxisRendererBase<MagnitudeAxis> {
    /**
     * Initializes a new instance of the MagnitudeAxisRenderer class.
     * @param rc The render context.
     * @param plot The plot.
     */
    constructor(rc: IRenderContext, plot: PlotModel);
    /**
     * Renders the specified axis.
     * @param axis The axis.
     * @param pass The pass.
     * @throws Error if angle axis is not defined.
     */
    render(axis: MagnitudeAxis, pass: number): Promise<void>;
    /**
     * Returns the angle (in radian) of the axis line in screen coordinate
     * @param axis The axis.
     * @param angleAxis The angle axis.
     * @returns The angle (in radians).
     */
    private static getActualAngle;
    /**
     * Choose the most appropriate alignment for tick text
     * @param actualAngle The actual angle.
     */
    private static getTickTextAlignment;
    /**
     * Renders a tick, chooses the best implementation
     * @param axis The axis.
     * @param angleAxis The angle axis.
     * @param x The x-value.
     * @param pen The pen.
     */
    private renderTick;
    /**
     * Renders a tick by drawing an ellipse
     * @param axis The axis.
     * @param angleAxis The angle axis.
     * @param x The x-value.
     * @param pen The pen.
     */
    private renderTickCircle;
    /**
     * Renders a tick by drawing a lot of segments
     * @param axis The axis.
     * @param angleAxis The angle axis.
     * @param x The x-value.
     * @param pen The pen.
     */
    private renderTickArc;
    /**
     * Renders major tick text
     * @param axis The axis.
     * @param x The x-value.
     * @param angleAxis The angle axis.
     */
    private renderTickText;
}
//# sourceMappingURL=MagnitudeAxisRenderer.d.ts.map