import { type AxisStringFormatterType, type CreateLinearAxisOptions, LinearAxis } from '..';
import { TimeSpan } from '../../patch';
export interface CreateTimeSpanAxisOptions extends CreateLinearAxisOptions {
}
export declare const DefaultTimeSpanAxisOptions: CreateTimeSpanAxisOptions;
export declare const ExtendedDefaultTimeSpanAxisOptions: {
    fractionUnit?: number | undefined;
    fractionUnitSymbol?: string | undefined;
    formatAsFractions?: boolean | undefined;
    position?: import('..').AxisPosition | undefined;
    positionTier?: number | undefined;
    isAxisVisible?: boolean | undefined;
    layer?: import('..').AxisLayer | undefined;
    absoluteMaximum?: number | undefined;
    absoluteMinimum?: number | undefined;
    minimum?: number | undefined;
    maximum?: number | undefined;
    minorStep?: number | undefined;
    majorStep?: number | undefined;
    minimumMinorStep?: number | undefined;
    minimumMajorStep?: number | undefined;
    minimumMajorIntervalCount?: number | undefined;
    maximumMajorIntervalCount?: number | undefined;
    minimumPadding?: number | undefined;
    maximumPadding?: number | undefined;
    minimumRange?: number | undefined;
    maximumRange?: number | undefined;
    minimumDataMargin?: number | undefined;
    maximumDataMargin?: number | undefined;
    minimumMargin?: number | undefined;
    maximumMargin?: number | undefined;
    tickStyle?: import('..').TickStyle | undefined;
    ticklineColor?: string | undefined;
    minorTicklineColor?: string | undefined;
    axislineStyle?: import('..').LineStyle | undefined;
    axislineColor?: string | undefined;
    axislineThickness?: number | undefined;
    majorGridlineStyle?: import('..').LineStyle | undefined;
    majorGridlineColor?: string | undefined;
    majorGridlineThickness?: number | undefined;
    minorGridlineStyle?: import('..').LineStyle | undefined;
    minorGridlineColor?: string | undefined;
    minorGridlineThickness?: number | undefined;
    extraGridlines?: number[] | undefined;
    extraGridlineStyle?: import('..').LineStyle | undefined;
    extraGridlineColor?: string | undefined;
    extraGridlineThickness?: number | undefined;
    minorTickSize?: number | undefined;
    majorTickSize?: number | undefined;
    startPosition?: number | undefined;
    stringFormatter?: AxisStringFormatterType | undefined;
    endPosition?: number | undefined;
    title?: string | undefined;
    titlePosition?: number | undefined;
    unit?: string | undefined;
    useSuperExponentialFormat?: boolean | undefined;
    titleFormatter?: import('..').AxisTitleFormatterType | undefined;
    titleClippingLength?: number | undefined;
    titleColor?: string | undefined;
    titleFontSize?: number | undefined;
    titleFontWeight?: number | undefined;
    clipTitle?: boolean | undefined;
    angle?: number | undefined;
    isZoomEnabled?: boolean | undefined;
    key?: string | undefined;
    isPanEnabled?: boolean | undefined;
    filterMinValue?: number | undefined;
    filterMaxValue?: number | undefined;
    filterFunction?: ((value: number) => boolean) | undefined;
    intervalLength?: number | undefined;
    axisDistance?: number | undefined;
    axisTitleDistance?: number | undefined;
    axisTickToLabelDistance?: number | undefined;
    dataMaximum?: number | undefined;
    dataMinimum?: number | undefined;
    labelFormatter?: AxisStringFormatterType | undefined;
    positionAtZeroCrossing?: boolean | undefined;
    cropGridlines?: boolean | undefined;
    positionTierMaxShift?: number | undefined;
    positionTierMinShift?: number | undefined;
    positionTierSize?: number | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Represents an axis presenting TimeSpan values.
 * The values should be in seconds.
 * The StringFormat value can be used to force formatting of the axis values
 * "h:mm" shows hours and minutes
 * "m:ss" shows minutes and seconds
 */
export declare class TimeSpanAxis extends LinearAxis {
    constructor(opt?: CreateTimeSpanAxisOptions);
    getElementName(): string;
    /**
     * Converts a time span to a double.
     * @param s The time span.
     * @returns A double value.
     */
    static toDouble(s: TimeSpan): number;
    /**
     * Converts a time span to a double.
     * @returns A double value.
     */
    itemToDouble(item: any): number;
    /**
     * Converts a double to a time span.
     * @param value The value.
     * @returns A time span.
     */
    static toTimeSpan(value: number): TimeSpan;
    /**
     * Gets the value from an axis coordinate, converts from double to the correct data type if necessary. e.g. DateTimeAxis returns the DateTime and CategoryAxis returns category strings.
     * @param x The coordinate.
     * @returns The value.
     */
    getValue(x: number): any;
    /**
     * Gets the default formatter.
     * @returns The default formatter.
     */
    protected getDefaultStringFormatter(): AxisStringFormatterType | undefined;
    /**
     * Formats the value to be used on the axis.
     * @param x The value to format.
     * @returns The formatted value.
     */
    protected formatValueOverride(x: number): string;
    /**
     * Calculates the actual interval.
     * @param availableSize The available size.
     * @param maxIntervalSize The maximum interval size.
     * @param minIntervalCount The minimum number of intervals.
     * @param maxIntervalCount The maximum number of intervals.
     * @returns The actual interval size.
     */
    protected calculateActualInterval(availableSize: number, maxIntervalSize: number, minIntervalCount: number, maxIntervalCount: number): number;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=TimeSpanAxis.d.ts.map