import { DataVector } from '..';
/**
 * Represents a point in the data space.
 * DataPoints are transformed to ScreenPoints.
 */
export interface DataPoint {
    /**
     * The x-coordinate.
     */
    x: number;
    /**
     * The y-coordinate.
     */
    y: number;
}
/**
 * The undefined.
 */
export declare const DataPoint_Undefined: DataPoint;
/**
 * The zero point.
 */
export declare const DataPoint_Zero: DataPoint;
export declare function DataPoint_isUnDefined(p: DataPoint): boolean;
/**
 * Determines whether this point is defined.
 * @returns true if this point is defined; otherwise, false.
 */
export declare function DataPoint_isDefined(p: DataPoint): boolean;
export declare function newDataPoint(x: number, y: number): DataPoint;
export declare function isDataPoint(d: any): any;
/**
 * Subtracts a DataPoint from a DataPoint
 * and returns the result as a DataVector.
 * @returns A DataVector structure that represents the difference between p1 and p2.
 */
export declare function dataPointMinus(p1: DataPoint, p2: DataPoint): DataVector;
/**
 * Subtracts a DataVector from a DataPoint
 * and returns the result as a DataPoint.
 * @returns A DataPoint that represents point translated by the negative vector.
 */
export declare function dataPointMinusVector(p1: DataPoint, v: DataVector): DataPoint;
/**
 * Translates a DataPoint by a DataVector.
 * @returns The translated point.
 */
export declare function dataPointPlus(p1: DataPoint, p2: DataPoint): DataPoint;
/**
 * Determines whether this and another specified DataPoint have the same value.
 * @returns true if the value of the other parameter is the same as the value of this instance; otherwise, false.
 */
export declare function dataPointEquals(p1: DataPoint, p2: DataPoint): boolean;
//# sourceMappingURL=DataPoint.d.ts.map