/**
 * Represents a vector in the data space.
 */
export declare class DataVector {
    /**
     * The undefined.
     */
    static readonly Undefined: DataVector;
    /**
     * The x-coordinate.
     */
    private readonly _x;
    /**
     * The y-coordinate.
     */
    private readonly _y;
    /**
     * Initializes a new instance of the DataVector class.
     * @param x The x-coordinate.
     * @param y The y-coordinate.
     */
    constructor(x: number, y: number);
    /**
     * Gets the length.
     */
    get length(): number;
    /**
     * Gets the length squared.
     */
    get lengthSquared(): number;
    /**
     * Gets the x-coordinate.
     */
    get x(): number;
    /**
     * Gets the y-coordinate.
     */
    get y(): number;
    /**
     * Implements the operator *.
     * @param d The multiplication factor.
     * @returns The result of the operator.
     */
    times(d: number): DataVector;
    /**
     * Adds a vector to another vector.
     * @param d The vector to be added.
     * @returns The result of the operation.
     */
    plus(d: DataVector): DataVector;
    /**
     * Subtracts one specified vector from another.
     * @param d The vector to be subtracted.
     * @returns The result of operation.
     */
    minus(d: DataVector): DataVector;
    /**
     * Negates the specified vector.
     * @returns The result of operation.
     */
    negate(): DataVector;
    /**
     * Determines whether this and another specified DataVector have the same value.
     * @param other The vector to compare to this instance.
     * @returns true if the value of the other parameter is the same as the value of this instance; otherwise, false.
     */
    equals(other: DataVector): boolean;
    /**
     * Returns a string that represents this instance.
     */
    toString(): string;
    /**
     * Determines whether this point is defined.
     * @returns true if this point is defined; otherwise, false.
     */
    isDefined(): boolean;
}
//# sourceMappingURL=DataVector.d.ts.map