import { type IViewCommand, type OxyInputGesture, OxyKey, OxyModifierKeys, OxyMouseButton } from '..';
/**
 * Represents a binding by an input gesture and a command binding.
 */
export declare class InputCommandBinding {
    /**
     * The gesture.
     */
    private readonly gesture;
    /**
     * The command.
     */
    private readonly command;
    /**
     * Initializes a new instance of the InputCommandBinding class by a gesture.
     * @param gesture The gesture.
     * @param command The command.
     */
    constructor(gesture: OxyInputGesture, command: IViewCommand);
    /**
     * Initializes a new instance of the InputCommandBinding class by a key gesture.
     * @param key The key.
     * @param modifiers The modifiers.
     * @param command The command.
     */
    static fromKeyGesture(key: OxyKey, modifiers: OxyModifierKeys, command: IViewCommand): InputCommandBinding;
    /**
     * Initializes a new instance of the InputCommandBinding class by a mouse gesture.
     * @param mouseButton The mouse button.
     * @param modifiers The modifiers.
     * @param command The command.
     */
    static fromMouseGesture(mouseButton: OxyMouseButton, modifiers: OxyModifierKeys, command: IViewCommand): InputCommandBinding;
    /**
     * Gets the gesture.
     */
    getGesture(): OxyInputGesture;
    /**
     * Gets the command.
     */
    getCommand(): IViewCommand;
}
//# sourceMappingURL=InputCommandBinding.d.ts.map