/**
 * Represents a selection of items (by index) and features (by enumeration type).
 */
export declare class Selection {
    /**
     * Static instance representing everything (all items and all features) selected.
     */
    private static readonly EverythingSelection;
    /**
     * The selection
     */
    private readonly selection;
    /**
     * Gets everything selected.
     */
    static get Everything(): Selection;
    /**
     * Determines whether everything is selected.
     */
    isEverythingSelected(): boolean;
    /**
     * Gets the indices of the selected items in this selection.
     */
    getSelectedItems(): number[];
    /**
     * Gets the selected items by the specified feature.
     * @param feature The feature.
     */
    getSelectedItemsByFeature(feature: any): number[];
    /**
     * Clears the selected items.
     */
    clear(): void;
    /**
     * Determines whether the specified item and feature is selected.
     * @param index The index of the item.
     * @param feature The feature.
     */
    isItemSelected(index: number, feature?: any): boolean;
    /**
     * Selects the specified item/feature.
     * @param index The index.
     * @param feature The feature.
     */
    select(index: number, feature?: any): void;
    /**
     * Unselects the specified item.
     * @param index The index of the item.
     * @param feature The feature.
     */
    unselect(index: number, feature?: any): void;
    private getSameKey;
    private hasSelection;
    private deleteSelection;
    private setSelection;
}
//# sourceMappingURL=Selection.d.ts.map