import type { ImageEncoderOptions, OxyColor } from '..';
import { ImageFormat } from '..';
import { type TwoDimensionalArray } from '../../patch';
/**
 * Represents an image.
 */
export interface OxyImage {
    /**
     * Gets or sets the URI of the image.
     * Not implemented.
     */
    uri?: string;
    /**
     * the image format.
     */
    format: ImageFormat;
    /**
     * the width of the image.
     */
    width: number;
    /**
     * the height of the image.
     */
    height: number;
    /**
     *  the number of bits per pixel.
     */
    bitsPerPixel: number;
    /**
     * the horizontal resolution of the image.
     */
    dpiX: number;
    /**
     * the vertical resolution of the image.
     */
    dpiY: number;
    /**
     * The image data.
     */
    data: number[];
}
/**
 * Represents an image.
 */
export declare class OxyImageEx implements OxyImage {
    private _image;
    constructor(image: OxyImage);
    static from(image: OxyImage): OxyImageEx;
    /**
     * Gets or sets the URI of the image.
     * Not implemented.
     */
    get uri(): string | undefined;
    /**
     * the image format.
     */
    get format(): ImageFormat;
    /**
     * the width of the image.
     */
    get width(): number;
    /**
     * the height of the image.
     */
    get height(): number;
    /**
     *  the number of bits per pixel.
     */
    get bitsPerPixel(): number;
    /**
     * the horizontal resolution of the image.
     */
    get dpiX(): number;
    /**
     * the vertical resolution of the image.
     */
    get dpiY(): number;
    /**
     * The image data.
     */
    get data(): number[];
    /**
     * Creates an image from 8-bit indexed pixels.
     * @param pixels The pixels indexed as [x,y]. [0,0] is top-left.
     * @param palette The palette.
     * @param format The image format.
     * @param encoderOptions The encoder options.
     * @returns An OxyImage
     */
    static create(pixels: TwoDimensionalArray<OxyColor> | TwoDimensionalArray<number>, format: ImageFormat, encoderOptions?: ImageEncoderOptions, palette?: OxyColor[]): Promise<OxyImage>;
    /**
     * Gets the image format.
     * @param bytes The image bytes.
     * @returns The ImageFormat
     */
    static getImageFormat(bytes: Uint8Array): ImageFormat;
    private _hashCode?;
    getHashCode(): number;
}
//# sourceMappingURL=OxyImage.d.ts.map