import { type CreateLegendBaseOptions, EdgeRenderingMode, HitTestArguments, type HitTestResult, HorizontalAlignment, type IRenderContext, LegendBase, LegendItemOrder, LegendOrientation, LegendPlacement, LegendPosition, LegendSymbolPlacement, type OxyColor, type OxyRect, type OxySize, type ScreenPoint, SelectionMode } from '..';
export interface CreateLegendOptions extends CreateLegendBaseOptions {
    groupNameFont?: string;
    groupNameFontSize?: number;
    groupNameFontWeight?: number;
    seriesInvisibleTextColor?: OxyColor;
}
export declare const DefaultLegendOptions: CreateLegendOptions;
export declare const ExtendedDefaultLegendOptions: {
    groupNameFont?: string | undefined;
    groupNameFontSize?: number | undefined;
    groupNameFontWeight?: number | undefined;
    seriesInvisibleTextColor?: string | undefined;
    key?: string | undefined;
    isLegendVisible?: boolean | undefined;
    legendOrientation?: LegendOrientation | undefined;
    legendPadding?: number | undefined;
    legendSymbolLength?: number | undefined;
    legendSymbolMargin?: number | undefined;
    legendSymbolPlacement?: LegendSymbolPlacement | undefined;
    legendTitle?: string | undefined;
    legendTitleColor?: string | undefined;
    legendTitleFont?: string | undefined;
    legendTitleFontSize?: number | undefined;
    legendTitleFontWeight?: number | undefined;
    legendBackground?: string | undefined;
    legendBorder?: string | undefined;
    legendBorderThickness?: number | undefined;
    legendColumnSpacing?: number | undefined;
    legendFont?: string | undefined;
    legendFontSize?: number | undefined;
    legendTextColor?: string | undefined;
    legendFontWeight?: number | undefined;
    legendItemAlignment?: HorizontalAlignment | undefined;
    legendItemOrder?: LegendItemOrder | undefined;
    legendItemSpacing?: number | undefined;
    legendLineSpacing?: number | undefined;
    legendMargin?: number | undefined;
    legendMaxWidth?: number | undefined;
    legendMaxHeight?: number | undefined;
    legendPlacement?: LegendPlacement | undefined;
    legendPosition?: LegendPosition | undefined;
    allowUseFullExtent?: boolean | undefined;
    showInvisibleSeries?: boolean | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: SelectionMode | undefined;
};
/**
 * Represents a Legend.
 */
export declare class Legend extends LegendBase {
    private _legendBox;
    private readonly _seriesPosMap;
    groupNameFont?: string;
    groupNameFontSize: number;
    groupNameFontWeight: number;
    seriesInvisibleTextColor: OxyColor;
    /**
     * Initializes a new instance of the Legend class.
     */
    constructor(opt?: CreateLegendOptions);
    getElementName(): string;
    /**
     * Override for legend hit test.
     * @param args Arguments passed to the hit test
     * @returns The hit test results.
     */
    protected legendHitTest(args: HitTestArguments): HitTestResult | undefined;
    /**
     * Checks if a screen point is within the legend boundaries.
     * @param point A screen point.
     * @returns A value indicating whether the point is inside legend boundaries or not.
     */
    isPointInLegend(point: ScreenPoint): boolean;
    /**
     * Makes the LegendOrientation property safe.
     * If Legend is positioned left or right, force it to vertical orientation
     */
    ensureLegendProperties(): void;
    /**
     * Renders or measures the legends.
     * @param rc The render context.
     */
    renderLegends(rc: IRenderContext): Promise<void>;
    /**
     * Measures the legend area and gets the legend size.
     * @param rc The rendering context.
     * @param availableLegendArea The area available to legend.
     */
    getLegendSize(rc: IRenderContext, availableLegendArea: OxySize): Promise<OxySize>;
    /**
     * Gets the rectangle of the legend box.
     * @param legendSize Size of the legend box.
     * @returns A rectangle.
     */
    getLegendRectangle(legendSize: OxySize): OxyRect;
    /**
     * Renders the legend for the specified series.
     * @param rc The render context.
     * @param s The series.
     * @param rect The position and size of the legend.
     */
    private renderLegend;
    /**
     * Measures the legends.
     * @param rc The render context.
     * @param availableSize The available size for the legend box.
     * @returns The size of the legend box.
     */
    private measureLegends;
    /**
     * Renders or measures the legends.
     * @param rc The render context.
     * @param rect Provides the available size if measuring, otherwise it provides the position and size of the legend.
     * @param measureOnly Specify if the size of the legend box should be measured only (not rendered).
     * @returns The size of the legend box.
     */
    private renderOrMeasureLegends;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=Legend.d.ts.map