import { Axis, AxisPreference, type DataPoint, type IPlotView, ManipulatorBase, type OxyInputEventArgs, type ScreenPoint } from '../..';
/**
 * Provides an abstract base class for plot manipulators.
 */
export declare abstract class PlotManipulator<T extends OxyInputEventArgs> extends ManipulatorBase<T> {
    /**
     * The plot view where the event was raised.
     */
    readonly plotView: IPlotView;
    /**
     * The axis that the manipulator will prefer to operate on.
     */
    axisPreference: AxisPreference;
    /**
     * The X axis.
     */
    protected xAxis: Axis | undefined;
    /**
     * The Y axis.
     */
    protected yAxis: Axis | undefined;
    /**
     * Initializes a new instance of the PlotManipulator class.
     * @param view The plot view.
     */
    protected constructor(view: IPlotView);
    /**
     * Transforms a point from screen coordinates to data coordinates.
     * @param x The x coordinate.
     * @param y The y coordinate.
     * @returns A data point.
     */
    protected inverseTransform(x: number, y: number): DataPoint;
    /**
     * Assigns the axes to this manipulator by the specified position.
     * @param position The position.
     */
    protected assignAxes(position: ScreenPoint): void;
}
//# sourceMappingURL=PlotManipulator.d.ts.map