import { type IPlotView, type OxyTouchEventArgs, TouchManipulator } from '../..';
export interface TouchTrackerManipulatorOptions {
    /**
     * Gets or sets a value indicating whether to show tracker on points only (not interpolating).
     */
    pointsOnly?: boolean;
    /**
     * Gets or sets a value indicating whether to snap to the nearest point.
     */
    snap?: boolean;
    /**
     * Gets or sets a value indicating whether to lock the tracker to the initial series.
     */
    lockToInitialSeries?: boolean;
    /**
     * Gets or sets the distance from the series at which the tracker fires.
     */
    firesDistance?: number;
    /**
     * Gets or sets a value indicating whether to check distance when showing tracker between data points.
     */
    checkDistanceBetweenPoints?: boolean;
}
/**
 * Provides a plot manipulator for tracker functionality.
 */
export declare class TouchTrackerManipulator extends TouchManipulator {
    /**
     * The current series.
     */
    private currentSeries?;
    /**
     * Initializes a new instance of the TouchTrackerManipulator class.
     */
    constructor(plotView: IPlotView, options?: TouchTrackerManipulatorOptions);
    /**
     * Gets or sets a value indicating whether to show tracker on points only (not interpolating).
     */
    pointsOnly: boolean;
    /**
     * Gets or sets a value indicating whether to snap to the nearest point.
     */
    snap: boolean;
    /**
     * Gets or sets a value indicating whether to lock the tracker to the initial series.
     */
    lockToInitialSeries: boolean;
    /**
     * Gets or sets the distance from the series at which the tracker fires.
     */
    firesDistance: number;
    /**
     * Gets or sets a value indicating whether to check distance when showing tracker between data points.
     */
    checkDistanceBetweenPoints: boolean;
    /**
     * Occurs when a manipulation is complete.
     * @param e The OxyTouchEventArgs instance containing the event data.
     */
    completed(e: OxyTouchEventArgs): void;
    /**
     * Occurs when a touch delta event is handled.
     * @param e The OxyTouchEventArgs instance containing the event data.
     */
    delta(e: OxyTouchEventArgs): void;
    /**
     * Occurs when an input device begins a manipulation on the plot.
     * @param e The OxyTouchEventArgs instance containing the event data.
     */
    started(e: OxyTouchEventArgs): void;
    /**
     * Updates the tracker to the specified position.
     * @param position The position.
     */
    private updateTracker;
}
//# sourceMappingURL=TouchTrackerManipulator.d.ts.map