import type { DataPoint, OxyRect, ScreenPoint, Series } from '../..';
import { Axis, PlotModel } from '../..';
export interface CreateTrackerHitResultOptions {
    dataPoint?: DataPoint;
    item?: any;
    index?: number;
    lineExtents?: OxyRect;
    plotModel?: PlotModel;
    position?: ScreenPoint;
    series?: Series;
    text?: string;
}
/**
 * Provides data for a tracker hit result.
 *
 * @remarks This is used as DataContext for the TrackerControl.
 * The TrackerControl is visible when the user use the left mouse button to "track" points on the series.
 */
export declare class TrackerHitResult {
    constructor(opt?: CreateTrackerHitResultOptions);
    /**
     * Gets or sets the nearest or interpolated data point.
     */
    dataPoint?: DataPoint;
    /**
     * Gets or sets the source item of the point.
     * If the current point is from an ItemsSource and is not interpolated, this property will contain the item.
     */
    item?: any;
    /**
     * Gets or sets the index for the Item.
     */
    index: number;
    /**
     * Gets or sets the horizontal/vertical line extents.
     */
    lineExtents?: OxyRect;
    /**
     * Gets or sets the plot model.
     */
    plotModel?: PlotModel;
    /**
     * Gets or sets the position in screen coordinates.
     */
    position?: ScreenPoint;
    /**
     * Gets or sets the series that is being tracked.
     */
    series?: Series;
    /**
     * Gets or sets the text shown in the tracker.
     */
    text?: string;
    /**
     * Gets the X axis.
     */
    get xAxis(): Axis | undefined;
    /**
     * Gets the Y axis.
     */
    get yAxis(): Axis | undefined;
    /**
     * Returns a string that represents this instance.
     */
    toString(): string;
}
//# sourceMappingURL=TrackerHitResult.d.ts.map