import { type IPlotView, MouseManipulator, type OxyMouseEventArgs } from '../..';
export interface TrackerManipulatorOptions {
    /**
     * Gets or sets a value indicating whether to show tracker on points only (not interpolating).
     */
    pointsOnly?: boolean;
    /**
     * Gets or sets a value indicating whether to snap to the nearest point.
     */
    snap?: boolean;
    /**
     * Gets or sets a value indicating whether to lock the tracker to the initial series.
     */
    lockToInitialSeries?: boolean;
    /**
     * Gets or sets the distance from the series at which the tracker fires.
     */
    firesDistance?: number;
    /**
     * Gets or sets a value indicating whether to check distance when showing tracker between data points.
     */
    checkDistanceBetweenPoints?: boolean;
}
/**
 * Provides a plot manipulator for tracker functionality.
 */
export declare class TrackerManipulator extends MouseManipulator {
    /**
     * The current series.
     */
    private currentSeries?;
    /**
     * Initializes a new instance of the TrackerManipulator class.
     */
    constructor(plotView: IPlotView, options?: TrackerManipulatorOptions);
    /**
     * Gets or sets a value indicating whether to show tracker on points only (not interpolating).
     */
    pointsOnly: boolean;
    /**
     * Gets or sets a value indicating whether to snap to the nearest point.
     */
    snap: boolean;
    /**
     * Gets or sets a value indicating whether to lock the tracker to the initial series.
     */
    lockToInitialSeries: boolean;
    /**
     * Gets or sets the distance from the series at which the tracker fires.
     */
    firesDistance: number;
    /**
     * Gets or sets a value indicating whether to check distance when showing tracker between data points.
     */
    checkDistanceBetweenPoints: boolean;
    /**
     * Gets or sets a value indicating whether to track annotations.
     */
    isTrackAnnotations: boolean;
    /**
     * Occurs when a manipulation is complete.
     * @param e The OxyMouseEventArgs instance containing the event data.
     */
    completed(e: OxyMouseEventArgs): void;
    /**
     * Occurs when the input device changes position during a manipulation.
     * @param e The OxyMouseEventArgs instance containing the event data.
     */
    delta(e: OxyMouseEventArgs): void;
    /**
     * Occurs when an input device begins a manipulation on the plot.
     * @param e The OxyMouseEventArgs instance containing the event data.
     */
    started(e: OxyMouseEventArgs): void;
    /**
     * Track Annotations
     */
    private trackAnnotations;
}
//# sourceMappingURL=TrackerManipulator.d.ts.map