import { type IViewCommandG, type OxyKeyEventArgs, type OxyMouseDownEventArgs, type OxyMouseEventArgs, type OxyMouseWheelEventArgs, type OxyTouchEventArgs } from '..';
/**
 * Defines common commands for the plots.
 */
export declare class PlotCommands {
    private static init;
    /**
     * Gets the reset axes command.
     */
    static reset: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the reset axes command (for mouse events).
     */
    static resetAt: IViewCommandG<OxyMouseEventArgs>;
    /**
     * Gets the pan/zoom touch command.
     */
    static panZoomByTouch: IViewCommandG<OxyTouchEventArgs>;
    /**
     * Gets the pan command.
     */
    static panAt: IViewCommandG<OxyMouseDownEventArgs>;
    /**
     * Gets the zoom rectangle command.
     */
    static zoomRectangle: IViewCommandG<OxyMouseDownEventArgs>;
    /**
     * Gets the zoom by mouse wheel command.
     */
    static zoomWheel: IViewCommandG<OxyMouseWheelEventArgs>;
    /**
     * Gets the fine-control zoom by mouse wheel command.
     */
    static zoomWheelFine: IViewCommandG<OxyMouseWheelEventArgs>;
    /**
     * Gets the tracker command.
     */
    static track: IViewCommandG<OxyMouseDownEventArgs>;
    /**
     * Gets the snap tracker command.
     */
    static snapTrack: IViewCommandG<OxyMouseDownEventArgs>;
    /**
     * Gets the snap tracker command.
     */
    static snapTrackTouch: IViewCommandG<OxyTouchEventArgs>;
    /**
     * Gets the points only tracker command.
     */
    static pointsOnlyTrack: IViewCommandG<OxyMouseDownEventArgs>;
    /**
     * Gets the points only tracker command.
     */
    static pointsOnlyTrackTouch: IViewCommandG<OxyTouchEventArgs>;
    /**
     * Gets the mouse hover tracker.
     */
    static hoverTrack: IViewCommandG<OxyMouseEventArgs>;
    /**
     * Gets the mouse hover snap tracker.
     */
    static hoverSnapTrack: IViewCommandG<OxyMouseEventArgs>;
    /**
     * Gets the mouse hover points only tracker.
     */
    static hoverPointsOnlyTrack: IViewCommandG<OxyMouseEventArgs>;
    /**
     * Gets the pan left command.
     */
    static panLeft: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the pan right command.
     */
    static panRight: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the pan up command.
     */
    static panUp: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the pan down command.
     */
    static panDown: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the fine control pan left command.
     */
    static panLeftFine: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the fine control pan right command.
     */
    static panRightFine: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the fine control pan up command.
     */
    static panUpFine: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the fine control pan down command.
     */
    static panDownFine: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the zoom in command.
     */
    static zoomInAt: IViewCommandG<OxyMouseEventArgs>;
    /**
     * Gets the zoom out command.
     */
    static zoomOutAt: IViewCommandG<OxyMouseEventArgs>;
    /**
     * Gets the zoom in command.
     */
    static zoomIn: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the zoom out command.
     */
    static zoomOut: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the fine control zoom in command.
     */
    static zoomInFine: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Gets the fine control zoom out command.
     */
    static zoomOutFine: IViewCommandG<OxyKeyEventArgs>;
    /**
     * Handles the reset event.
     * @param view The view to reset.
     * @param args The OxyInputEventArgs instance containing the event data.
     */
    private static handleReset;
    /**
     * Zooms the view by the specified factor at the position specified in the OxyMouseEventArgs.
     * @param view The view.
     * @param args The OxyMouseWheelEventArgs instance containing the event data.
     * @param delta The zoom factor.
     */
    private static handleZoomAt;
    /**
     * Zooms the view by the mouse wheel delta in the specified OxyKeyEventArgs.
     * @param view The view.
     * @param args The OxyMouseWheelEventArgs instance containing the event data.
     * @param factor The zoom speed factor. Default value is 1.
     */
    private static handleZoomByWheel;
    /**
     * Zooms the view by the key in the specified factor.
     * @param view The view.
     * @param args The OxyInputEventArgs instance containing the event data.
     * @param delta The zoom factor (positive zoom in, negative zoom out).
     */
    private static handleZoomCenter;
    /**
     * Pans the view by the key in the specified vector.
     * @param view The view.
     * @param args The OxyInputEventArgs instance containing the event data.
     * @param dx The horizontal delta (percentage of plot area width).
     * @param dy The vertical delta (percentage of plot area height).
     */
    private static handlePan;
}
//# sourceMappingURL=PlotCommands.d.ts.map