import { type CreateElementOptions, EdgeRenderingMode, Element, type IPlotElement, type OxyColor, type OxyRect, type PlotModel } from '..';
export interface CreatePlotElementOptions extends CreateElementOptions {
    font?: string;
    fontSize?: number;
    fontWeight?: number;
    tag?: any;
    textColor?: OxyColor;
    edgeRenderingMode?: EdgeRenderingMode;
    toolTip?: string;
}
export declare const DefaultPlotElementOptions: CreatePlotElementOptions;
export declare const ExtendedDefaultPlotElementOptions: {
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
};
/**
 * Provides an abstract base class for elements of a PlotModel.
 */
export declare abstract class PlotElement extends Element implements IPlotElement {
    /**
     * The font. The default is null (use PlotModel.DefaultFont).
     * If the value is null, the DefaultFont of the parent PlotModel will be used.
     */
    font?: string;
    /**
     * The size of the font. The default is NaN (use PlotModel.DefaultFontSize).
     * If the value is NaN, the DefaultFontSize of the parent PlotModel will be used.
     */
    fontSize: number;
    /**
     * The font weight. The default is normal.
     */
    fontWeight: number;
    /**
     * An arbitrary object value that can be used to store custom information about this plot element. The default is null.
     * This property is analogous to Tag properties in other Microsoft programming models. Tag is intended to provide a pre-existing property location where you can store some basic custom information about any PlotElement without requiring you to subclass an element.
     */
    tag?: any;
    /**
     * The color of the text. The default is OxyColors.Automatic (use PlotModel.TextColor).
     * If the value is OxyColors.Automatic, the TextColor of the parent PlotModel will be used.
     */
    textColor: OxyColor;
    /**
     * The edge rendering mode that is used for rendering the plot element.
     * The default is EdgeRenderingMode.Automatic.
     */
    edgeRenderingMode: EdgeRenderingMode;
    /**
     * The tool tip. The default is null.
     */
    toolTip?: string;
    /**
     * Initializes a new instance of the PlotElement class.
     */
    protected constructor(opt?: CreatePlotElementOptions);
    /**
     * Gets the parent PlotModel.
     */
    get plotModel(): PlotModel;
    /**
     * Gets the actual font.
     * @internal
     */
    get actualFont(): string;
    /**
     * Gets the actual size of the font.
     * @internal
     */
    get actualFontSize(): number;
    /**
     * Gets the actual font weight.
     * @internal
     */
    get actualFontWeight(): number;
    /**
     * Gets the actual color of the text.
     * @internal
     */
    get actualTextColor(): OxyColor;
    getClippingRect(): OxyRect;
    private _plotElementId?;
    /**
     * Returns a hash code for this element.
     * This method creates the hash code by reflecting the value of all public properties.
     * @returns A hash code for this instance, suitable for use in hashing algorithms and data structures like a hash table.
     */
    getElementHashCode(): number;
}
//# sourceMappingURL=PlotElement.d.ts.map