import type { DataPoint, ITransposablePlotElement, IXyAxisPlotElement, ScreenPoint, ScreenVector } from '..';
import { HorizontalAlignment, VerticalAlignment } from '..';
/**
 * The transposable plot element extensions.
 */
export declare class PlotElementExtensions {
    /**
     * Transforms from a screen point to a data point by the axes of this series.
     * @param element The ITransposablePlotElement.
     * @param x The x coordinate of the screen point.
     * @param y The y coordinate of the screen point.
     * @returns A data point.
     */
    static inverseTransform(element: IXyAxisPlotElement, x: number, y: number): DataPoint;
    /**
     * Checks if the series is transposed.
     * @param element The ITransposablePlotElement.
     * @returns True if the series is transposed, False otherwise.
     */
    static isTransposed(element: ITransposablePlotElement): boolean;
    /**
     * Transposes the ScreenPoint if the series is transposed.
     * @param element The ITransposablePlotElement.
     * @param point The ScreenPoint to orientate.
     * @returns The oriented point.
     */
    static orientate(element: ITransposablePlotElement, point: ScreenPoint): ScreenPoint;
    /**
     * Transposes the ScreenVector if the series is transposed. Reverses the respective direction if X or Y axis are reversed.
     * @param element The ITransposablePlotElement.
     * @param vector The ScreenVector to orientate.
     * @returns The oriented vector.
     */
    static orientateVector(element: ITransposablePlotElement, vector: ScreenVector): ScreenVector;
    /**
     * Orientates a HorizontalAlignment and a VerticalAlignment according to whether the Series is transposed or the Axes are reversed.
     * @param element The ITransposablePlotElement.
     * @param ha The HorizontalAlignment to orientate.
     * @param va The VerticalAlignment to orientate.
     */
    static orientateAlignment(element: ITransposablePlotElement, ha: HorizontalAlignment, va: VerticalAlignment): [HorizontalAlignment, VerticalAlignment];
    /**
     * Transforms the specified data point to a screen point by the axes of this series.
     * @param element The ITransposablePlotElement.
     * @param x The x coordinate of the data point.
     * @param y The y coordinate of the data point.
     * @returns A screen point.
     */
    static transform(element: IXyAxisPlotElement, x: number, y: number): ScreenPoint;
}
//# sourceMappingURL=PlotElementExtensions.d.ts.map