import { type DataPoint, type ITransposablePlotElement, type IXyAxisPlotElement, type OxyRect, type ScreenPoint } from '..';
/**
 * Provides utility functions for plot elements.
 */
export declare class PlotElementUtilities {
    /**
     * Gets the clipping rectangle defined by the Axis the IXyAxisPlotElement uses.
     * @param element The IXyAxisPlotElement.
     * @returns The clipping rectangle.
     */
    static getClippingRect(element: IXyAxisPlotElement): OxyRect;
    /**
     * Transforms from a screen point to a data point by the axes of this series.
     * @param element The ITransposablePlotElement.
     * @param p The screen point.
     * @returns A data point.
     */
    static inverseTransform(element: IXyAxisPlotElement, p: ScreenPoint): DataPoint;
    /**
     * Transforms from a screen point to a data point by the axes of this series while being aware of the orientation.
     * @param element The ITransposablePlotElement.
     * @param p The screen point.
     * @returns A data point.
     */
    static inverseTransformOrientated(element: ITransposablePlotElement, p: ScreenPoint): DataPoint;
    /**
     * Transforms the specified coordinates to a screen point by the axes of the plot element.
     * @param element The plot element.
     * @param p The data point.
     * @returns A screen point.
     */
    static transform(element: IXyAxisPlotElement, p: DataPoint): ScreenPoint;
    /**
     * Transforms the specified coordinates to a screen point by the axes of the plot element while being aware of the orientation.
     * @param element The plot element.
     * @param p The data point.
     * @returns A screen point.
     */
    static transformOrientated(element: ITransposablePlotElement, p: DataPoint): ScreenPoint;
}
//# sourceMappingURL=PlotElementUtilities.d.ts.map