import { HorizontalAlignment, VerticalAlignment } from './Alignments';
import { type ScreenPoint } from './ScreenPoint';
import { type OxyRect } from './OxyRect';
/**
 * Describes the size of an object.
 */
export interface OxySize {
    /**
     * The height
     */
    height: number;
    /**
     * The width
     */
    width: number;
}
/**
 * Initializes a new OxySize object.
 * @param width The width.
 * @param height The height.
 */
export declare function newOxySize(width?: number, height?: number): Readonly<OxySize>;
export declare const OxySize_Empty: Readonly<Readonly<OxySize>>;
export declare class OxySizeEx implements OxySize {
    private _size;
    constructor(size: OxySize);
    get height(): number;
    get width(): number;
    static from(size: OxySize): OxySizeEx;
    /**
     * Determines whether this instance and another specified OxySize object have the same value.
     * @returns true if the value of the other parameter is the same as the value of this instance; otherwise, false.
     */
    static equals(s: OxySize, other: OxySize): boolean;
    /**
     * Creates a new OxySize with the maximum dimensions of this instance and the specified other instance.
     * @returns A new OxySize.
     */
    static include(s: OxySize, other: OxySize): OxySize;
    /**
     * Calculates the bounds with respect to rotation angle and horizontal/vertical alignment.
     * @param bounds The size of the object to calculate bounds for.
     * @param angle The rotation angle (degrees).
     * @param horizontalAlignment The horizontal alignment.
     * @param verticalAlignment The vertical alignment.
     * @returns A minimum bounding rectangle.
     */
    static getBounds(bounds: OxySize, angle: number, horizontalAlignment: HorizontalAlignment, verticalAlignment: VerticalAlignment): OxyRect;
    /**
     * Gets the polygon outline of the specified rotated and aligned box.
     * @param size The size of the box.
     * @param origin The origin of the box.
     * @param angle The rotation angle of the box.
     * @param horizontalAlignment The horizontal alignment of the box.
     * @param verticalAlignment The vertical alignment of the box.
     * @returns A sequence of points defining the polygon outline of the box.
     */
    static getPolygon(size: OxySize, origin: ScreenPoint, angle: number, horizontalAlignment: HorizontalAlignment, verticalAlignment: VerticalAlignment): ScreenPoint[];
}
//# sourceMappingURL=OxySize.d.ts.map