import { type OxyRect, RenderContextBase } from '../..';
/**
 * Provides an abstract base class for rendering contexts that implements a clipping stack.
 */
export declare abstract class ClippingRenderContext extends RenderContextBase {
    private clipStack;
    /**
     * Pops the clip.
     */
    popClip(): void;
    /**
     * Pushes the clip.
     * @param clippingRectangle The clipping rectangle.
     */
    pushClip(clippingRectangle: OxyRect): void;
    /**
     * Gets the clip count.
     */
    get clipCount(): number;
    /**
     * Resets the clipping area.
     */
    protected abstract resetClip(): void;
    /**
     * Sets the clipping area to the specified rectangle.
     * @param clippingRectangle The rectangle.
     */
    protected abstract setClip(clippingRectangle: OxyRect): void;
}
//# sourceMappingURL=ClippingRenderContext.d.ts.map