import { HorizontalAlignment, type IRenderContext, type OxyColor, type OxySize, type ScreenPoint, VerticalAlignment } from '../..';
/**
 * Provides functionality to render mathematical expressions.
 */
export declare class MathRenderingExtensions {
    /**
     * Draws or measures text containing sub- and superscript.
     * @param rc The render context.
     * @param pt The point.
     * @param text The text.
     * @param textColor Color of the text.
     * @param fontFamily The font family.
     * @param fontSize The font size.
     * @param fontWeight The font weight.
     * @param angle The angle.
     * @param ha The horizontal alignment.
     * @param va The vertical alignment.
     * @param maxSize The maximum size of the text.
     * @param measure Measure the size of the text if set to true.
     * @returns The size of the text.
     */
    static drawMathText(rc: IRenderContext, pt: ScreenPoint, text: string, textColor: OxyColor, fontFamily: string, fontSize: number, fontWeight: number, angle: number, ha: HorizontalAlignment, va: VerticalAlignment, maxSize?: OxySize, measure?: boolean): Promise<OxySize>;
    /**
     * The measure math text.
     * @param rc The render context.
     * @param text The text.
     * @param fontFamily The font family.
     * @param fontSize The font size.
     * @param fontWeight The font weight.
     * @returns The size of the text.
     */
    static measureMathText(rc: IRenderContext, text: string, fontFamily: string, fontSize: number, fontWeight: number): Promise<OxySize>;
    /**
     * Draws text with sub- and superscript items.
     * @param rc The render context.
     * @param x The x.
     * @param y The y.
     * @param dx The x offset (in rotated coordinates).
     * @param dy The y offset (in rotated coordinates).
     * @param s The s.
     * @param textColor The text color.
     * @param fontFamily The font family.
     * @param fontSize The font size.
     * @param fontWeight The font weight.
     * @param measureOnly Only measure if set to true.
     * @param angle The angle of the text (degrees).
     * @returns The size of the text.
     */
    private static internalDrawMathText;
}
//# sourceMappingURL=MathRenderingExtensions.d.ts.map