import { type ScreenVector, ScreenVectorEx } from '..';
/**
 * Represents a point defined in screen space.
 *
 * @remarks The rendering methods transforms `DataPoint`s to `ScreenPoint`s.
 */
export interface ScreenPoint {
    /**
     * The x-coordinate.
     */
    x: number;
    /**
     * The y-coordinate.
     */
    y: number;
}
/**
 * The undefined point.
 */
export declare const ScreenPoint_Undefined: ScreenPoint;
/**
 * The left-top point.
 */
export declare const ScreenPoint_LeftTop: ScreenPoint;
export declare function newScreenPoint(x: number, y: number): ScreenPoint;
/**
 * Translates a ScreenPoint by a ScreenVector.
 * @returns The translated point.
 */
export declare function screenPointPlus(p1: ScreenPoint, p2: ScreenVector): ScreenPoint;
/**
 * Subtracts a ScreenPoint from a ScreenPoint
 * and returns the result as a ScreenVector.
 * @returns A ScreenVector structure that represents the difference between p1 and p2.
 */
export declare function screenPointMinus(p1: ScreenPoint, p2: ScreenPoint): ScreenVector;
export declare function screenPointMinusEx(p1: ScreenPoint, p2: ScreenPoint): ScreenVectorEx;
/**
 * Subtracts a ScreenVector from a ScreenPoint
 * and returns the result as a ScreenPoint.
 * @returns A ScreenPoint that represents point translated by the negative vector.
 */
export declare function screenPointMinusVector(point: ScreenPoint, vector: ScreenVector): ScreenPoint;
/**
 * Gets the distance to the specified point.
 * @returns The distance.
 */
export declare function screenPointDistanceTo(point: ScreenPoint, other: ScreenPoint): number;
/**
 * Gets the squared distance to the specified point.
 * @returns The squared distance.
 */
export declare function screenPointDistanceToSquared(point: ScreenPoint, other: ScreenPoint): number;
/**
 * Determines whether the specified point is undefined.
 * @returns `true` if the specified point is undefined; otherwise, `false`.
 */
export declare function ScreenPoint_isUndefined(point: ScreenPoint): boolean;
/**
 * Determines whether this instance and another specified `ScreenPoint` object have the same value.
 * @returns `true` if the value of the `other` parameter is the same as the value of this instance; otherwise, `false`.
 */
export declare function screenPointEquals(a: ScreenPoint, b: ScreenPoint): boolean;
//# sourceMappingURL=ScreenPoint.d.ts.map