import { type ScreenPoint } from '..';
/**
 * Provides algorithms for polygons and lines of ScreenPoint.
 */
export declare class ScreenPointHelper {
    /**
     * Finds the nearest point on the specified polyline.
     * @param point The point.
     * @param points The points.
     * @returns The nearest point.
     * @throws Error if points is null.
     */
    static findNearestPointOnPolyline(point: ScreenPoint, points: ScreenPoint[]): ScreenPoint;
    /**
     * Finds the point on line.
     * @param p The point.
     * @param p1 The first point on the line.
     * @param p2 The second point on the line.
     * @returns The nearest point on the line.
     * @remakes http://paulbourke.net/geometry/pointlineplane/
     */
    static findPointOnLine(p: ScreenPoint, p1: ScreenPoint, p2: ScreenPoint): ScreenPoint;
    /**
     * Finds the nearest point on line.
     * @param p The point.
     * @param p1 The start point on the line.
     * @param p2 The end point on the line.
     * @returns The relative position of the nearest point.
     * @remakes http://paulbourke.net/geometry/pointlineplane/
     */
    static findPositionOnLine(p: ScreenPoint, p1: ScreenPoint, p2: ScreenPoint): number;
    /**
     * Determines whether the specified point is in the specified polygon.
     * @param p The point.
     * @param pts The polygon points.
     * @returns true if the point is in the polygon; otherwise, false.
     */
    static isPointInPolygon(p: ScreenPoint, pts: ScreenPoint[]): boolean;
    /**
     * Resamples the points with the specified point distance limit.
     * @param allPoints All points.
     * @param minimumDistance The minimum squared distance.
     * @returns List of resampled points.
     */
    static resamplePoints(allPoints: ScreenPoint[], minimumDistance: number): ScreenPoint[];
    /**
     * Gets the centroid of the specified polygon.
     * @param points The points.
     * @returns The centroid.
     */
    static getCentroid(points: ScreenPoint[]): ScreenPoint;
}
//# sourceMappingURL=ScreenPointHelper.d.ts.map