/**
 * Represents a vector defined in screen space.
 */
export interface ScreenVector {
    /**
     * The x-coordinate.
     */
    x: number;
    /**
     * The y-coordinate.
     */
    y: number;
}
export declare function newScreenVector(x: number, y: number): ScreenVector;
export declare function newScreenVectorEx(x: number, y: number): ScreenVectorEx;
/**
 * The zero point.
 */
export declare const ScreenVector_Zero: ScreenVector;
export declare class ScreenVectorEx implements ScreenVector {
    private _v;
    get x(): number;
    get y(): number;
    get vector(): ScreenVector;
    constructor(v: ScreenVector);
    get length(): number;
    get lengthSquared(): number;
    minus(d: ScreenVector): ScreenVectorEx;
    times(d: number): ScreenVectorEx;
    negate(): ScreenVectorEx;
    normalize(): this;
    static fromVector(v: ScreenVector): ScreenVectorEx;
    static fromXY(x: number, y: number): ScreenVectorEx;
}
export declare class ScreenVectorHelper {
    /**
     * Gets the length of the vector.
     */
    static length(v: ScreenVector): number;
    /**
     * Gets the squared length of the vector.
     */
    static lengthSquared(v: ScreenVector): number;
    /**
     * Normalizes the vector (makes its length 1).
     * If the vector has zero length, it remains unchanged.
     */
    static normalize(v: ScreenVector): ScreenVector;
    static plus(v: ScreenVector, d: ScreenVector): ScreenVector;
    static minus(v: ScreenVector, d: ScreenVector): ScreenVector;
    static times(v: ScreenVector, d: number): ScreenVector;
    static negate(v: ScreenVector): ScreenVector;
    /**
     * Determines whether this vector equals another vector.
     * @param v
     * @param other The vector to compare to.
     * @returns True if the vectors are equal, false otherwise.
     */
    static equals(v: ScreenVector, other: ScreenVector): boolean;
}
//# sourceMappingURL=ScreenVector.d.ts.map