import type { DataPoint, IInterpolationAlgorithm, ScreenPoint } from '../..';
/**
 * Provides functionality to interpolate a list of points by a canonical spline.
 * Based on CanonicalSplineHelper.cs (c) 2009 by Charles Petzold (WPF and Silverlight)
 * http://www.charlespetzold.com/blog/2009/01/Canonical-Splines-in-WPF-and-Silverlight.html
 */
export declare class CanonicalSpline implements IInterpolationAlgorithm {
    /**
     * The tension.
     */
    tension: number;
    /**
     * Initializes a new instance of the CanonicalSpline class.
     * @param tension The tension.
     */
    constructor(tension: number);
    /**
     * Creates a spline of data points.
     * @param points The points.
     * @param isClosed True if the spline is closed.
     * @param tolerance The tolerance.
     * @returns A list of data points.
     */
    createSplineDp(points: DataPoint[], isClosed: boolean, tolerance: number): DataPoint[];
    /**
     * Creates a spline of screen points.
     * @param points The points.
     * @param isClosed True if the spline is closed.
     * @param tolerance The tolerance.
     * @returns A list of screen points.
     */
    createSplineSp(points: ScreenPoint[], isClosed: boolean, tolerance: number): ScreenPoint[];
    private static createSplineForDp;
    private static createSpline;
    private static segment;
}
//# sourceMappingURL=CanonicalSpline.d.ts.map