import { type CreateLineSeriesOptions, type DataPoint, type IRenderContext, LineSeries, LineStyle, type OxyColor, type OxyRect, type PlotModelSerializeOptions, type ScreenPoint, TrackerHitResult } from '..';
export interface CreateAreaSeriesOptions extends CreateLineSeriesOptions {
    /**
     * Gets or sets a constant value for the area definition.
     * This is used if DataFieldBase and BaselineValues are undefined.
     */
    constantY2?: number;
    /**
     * Gets or sets the data field to use for the X-coordinates of the second data set.
     */
    dataFieldX2?: string;
    /**
     * Gets or sets the data field to use for the Y-coordinates of the second data set.
     */
    dataFieldY2?: string;
    /**
     * Gets or sets the color of the line for the second data set.
     */
    color2?: OxyColor;
    /**
     * Gets or sets the fill color of the area.
     */
    fill?: OxyColor;
    /**
     * Gets or sets a value indicating whether the second data collection should be reversed.
     */
    reverse2?: boolean;
    points2?: DataPoint[];
}
export declare const DefaultAreaSeriesOptions: CreateAreaSeriesOptions;
export declare const ExtendedDefaultAreaSeriesOptions: {
    /**
     * Gets or sets a constant value for the area definition.
     * This is used if DataFieldBase and BaselineValues are undefined.
     */
    constantY2?: number | undefined;
    /**
     * Gets or sets the data field to use for the X-coordinates of the second data set.
     */
    dataFieldX2?: string | undefined;
    /**
     * Gets or sets the data field to use for the Y-coordinates of the second data set.
     */
    dataFieldY2?: string | undefined;
    /**
     * Gets or sets the color of the line for the second data set.
     */
    color2?: string | undefined;
    /**
     * Gets or sets the fill color of the area.
     */
    fill?: string | undefined;
    /**
     * Gets or sets a value indicating whether the second data collection should be reversed.
     */
    reverse2?: boolean | undefined;
    points2?: DataPoint[] | undefined;
    color?: string | undefined;
    brokenLineColor?: string | undefined;
    brokenLineStyle?: LineStyle | undefined;
    brokenLineThickness?: number | undefined;
    dashes?: number[] | undefined;
    decimator?: ((points: ScreenPoint[], result: ScreenPoint[]) => void) | undefined;
    labelStringFormatter?: import('..').LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    lineLegendPosition?: import('..').LineLegendPosition | undefined;
    markerFill?: string | undefined;
    markerOutline?: ScreenPoint[] | undefined;
    markerResolution?: number | undefined;
    markerSize?: number | undefined;
    markerStroke?: string | undefined;
    markerStrokeThickness?: number | undefined;
    markerType?: import('..').MarkerType | undefined;
    minimumSegmentLength?: number | undefined;
    interpolationAlgorithm?: import('..').IInterpolationAlgorithm | undefined;
    strokeThickness?: number | undefined;
    points?: DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('..').CreateXYAxisSeriesOptions;
};
/**
 * Represents an area series that fills the polygon defined by two sets of points or one set of points and a constant.
 */
export declare class AreaSeries extends LineSeries {
    /**
     * The second list of points.
     */
    private readonly _points2;
    /**
     * The secondary data points from the ItemsSource collection.
     */
    private readonly _itemsSourcePoints2;
    /**
     * The secondary data points from the Points2 list.
     */
    private _actualPoints2?;
    /**
     * Initializes a new instance of the AreaSeries class.
     */
    constructor(opt?: CreateAreaSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets a constant value for the area definition.
     * This is used if DataFieldBase and BaselineValues are undefined.
     */
    constantY2: number;
    /**
     * Gets or sets the data field to use for the X-coordinates of the second data set.
     */
    dataFieldX2?: string;
    /**
     * Gets or sets the data field to use for the Y-coordinates of the second data set.
     */
    dataFieldY2?: string;
    /**
     * Gets or sets the color of the line for the second data set.
     */
    color2: OxyColor;
    /**
     * Gets the actual color of the line for the second data set.
     */
    get actualColor2(): OxyColor;
    /**
     * Gets or sets the fill color of the area.
     */
    fill: OxyColor;
    /**
     * Gets the actual fill color of the area.
     */
    get actualFill(): OxyColor;
    /**
     * Gets the second list of points.
     */
    get points2(): DataPoint[];
    /**
     * Gets or sets a value indicating whether the second data collection should be reversed.
     */
    reverse2: boolean;
    /**
     * Gets the actual points of the second data set.
     */
    protected get actualPoints2(): DataPoint[];
    /**
     * Gets or sets the last visible window start position in second data points collection.
     */
    protected windowStartIndex2: number;
    /**
     * Gets a value indicating whether Points2 collection was defined by user.
     */
    protected isPoints2Defined: boolean;
    /**
     * Gets the nearest point.
     * @param point The point.
     * @param interpolate interpolate if set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the series on the specified rendering context.
     * @param rc The rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Renders the legend symbol for the line series on the
     * specified rendering context.
     * @param rc The rendering context.
     * @param legendBox The bounding rectangle of the legend box.
     */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * The update data.
     * @internal
     */
    updateData(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Renders data points skipping NaN values.
     * @param context Area rendering context.
     * @returns The list of chunks.
     */
    protected renderChunkedPoints(context: AreaRenderContext): Promise<ScreenPoint[][]>;
    /**
     * Renders a chunk of points on the screen.
     * @param context Render context.
     * @param points Screen points.
     * @returns The list of resampled points.
     */
    protected renderScreenPoints(context: AreaRenderContext, points: ScreenPoint[]): Promise<ScreenPoint[]>;
    /**
     * Gets the points when ConstantY2 is used.
     * @returns A sequence of DataPoint.
     */
    private getConstantPoints2;
    protected getJsonIgnoreProperties(): string[];
    protected getElementDefaultValues(): any;
    toJSON(opt?: PlotModelSerializeOptions): any;
}
/**
 * Holds parameters for point rendering.
 */
export declare class AreaRenderContext {
    /**
     * Gets or sets source data points.
     */
    points: DataPoint[];
    /**
     * Gets or sets start index of a visible window.
     */
    windowStartIndex: number;
    /**
     * Gets or sets maximum visible X coordinate.
     */
    xMax: number;
    /**
     * Gets or sets render context.
     */
    renderContext?: IRenderContext;
    /**
     * Gets or sets minimum squared distance between points.
     */
    minDistSquared: number;
    /**
     * Gets or sets a value indicating whether to reverse the points.
     */
    reverse: boolean;
    /**
     * Gets or sets line color.
     */
    color: OxyColor;
    /**
     * Gets or sets line dash array.
     */
    dashArray?: number[];
}
//# sourceMappingURL=AreaSeries.d.ts.map