import { type OxyColor } from '../..';
/**
 * Represents an item in a bar series.
 */
export interface BarItemBase {
    /**
     * The index of the category.
     */
    categoryIndex: number;
}
/**
 * Represents an item used in the BarSeries.
 */
export interface BarItem extends BarItemBase {
    /**
     * The color of the item.
     * If the color is not specified (default), the color of the series will be used.
     */
    color: OxyColor;
    /**
     * The value of the item.
     */
    value: number;
}
export declare function newBarItem(value?: number, categoryIndex?: number, color?: OxyColor): BarItem;
export declare function newBarItem(bi?: Partial<BarItem>): BarItem;
export declare function getBarItemCategoryIndex(bi: BarItemBase, defaultIndex: number): number;
export declare class BarItemEx implements BarItem {
    private readonly _barItem;
    constructor(barItem: BarItem);
    get color(): OxyColor;
    get value(): number;
    get categoryIndex(): number;
    /**
     * Gets the index of the category.
     * @param defaultIndex The default index.
     * @returns The index.
     * @internal
     */
    getCategoryIndex(defaultIndex: number): number;
    static fromBarItem(barItem: BarItem): BarItemEx;
}
//# sourceMappingURL=BarItem.d.ts.map