import { type BarItem, BarSeriesBase, type CreateBarSeriesBaseOptions, EdgeRenderingMode, type IRenderContext, type IStackableSeries, type LabelStringFormatterType, type OxyColor, type OxyRect, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterArgs } from '../..';
export interface CreateBarSeriesOptions extends CreateBarSeriesBaseOptions {
    valueField?: string;
    colorField?: string;
    stackGroup?: string;
    baseLine?: number;
    isStacked?: boolean;
    overlapsStack?: boolean;
    baseValue?: number;
    fillColor?: OxyColor;
    negativeFillColor?: OxyColor;
}
export interface BarSeriesTrackerStringFormatterArgs extends TrackerStringFormatterArgs {
    readonly item?: BarItem;
    readonly category?: string;
    readonly value?: number;
}
/**
 * The default tracker formatter
 */
export declare const DefaultBarSeriesTrackerFormatter: BarSeriesTrackerStringFormatterType;
export declare const DefaultBarSeriesOptions: CreateBarSeriesOptions;
export declare const ExtendedDefaultBarSeriesOptions: {
    valueField?: string | undefined;
    colorField?: string | undefined;
    stackGroup?: string | undefined;
    baseLine?: number | undefined;
    isStacked?: boolean | undefined;
    overlapsStack?: boolean | undefined;
    baseValue?: number | undefined;
    fillColor?: string | undefined;
    negativeFillColor?: string | undefined;
    barWidth?: number | undefined;
    strokeColor?: string | undefined;
    strokeThickness?: number | undefined;
    labelColor?: string | undefined;
    labelMargin?: number | undefined;
    labelAngle?: number | undefined;
    labelPlacement?: import('../..').LabelPlacement | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    items?: import('../..').BarItemBase[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('../..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('../..').CreateXYAxisSeriesOptions;
};
export type BarSeriesTrackerStringFormatterType = (args: BarSeriesTrackerStringFormatterArgs) => string | undefined;
/**
 * Represents a series for clustered or stacked bar charts.
 */
export declare class BarSeries extends BarSeriesBase<BarItem> implements IStackableSeries {
    /**
     * The default fill color.
     */
    private _defaultFillColor;
    /**
     * A format function used for the tracker. The default depends on the series.
     * The arguments for the formatter may be different for each type of series. See the documentation.
     */
    trackerStringFormatter?: BarSeriesTrackerStringFormatterType;
    /**
     * Initializes a new instance of the BarSeries class.
     */
    constructor(opt?: CreateBarSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the base value. Default value is 0.
     */
    baseValue: number;
    /**
     * Gets or sets the base value.
     */
    baseLine: number;
    private _actualBaseLine;
    /**
     * Gets or sets the actual baseline.
     */
    get actualBaseLine(): number;
    protected set actualBaseLine(value: number);
    /**
     * Gets the actual fill color.
     */
    get actualFillColor(): OxyColor;
    /**
     * Gets or sets the color field.
     */
    colorField?: string;
    /**
     * Gets or sets the color of the interior of the bars.
     */
    fillColor: OxyColor;
    /**
     * Gets or sets a value indicating whether the series is stacked.
     */
    isStacked: boolean;
    /**
     *  Gets a value indicating whether this series should overlap its stack when IsStacked is true.
     */
    overlapsStack: boolean;
    /**
     * Gets or sets the label formatter.
     */
    labelStringFormatter?: LabelStringFormatterType;
    /**
     * Gets or sets the color of the interior of the bars when the value is negative.
     */
    negativeFillColor: OxyColor;
    /**
     * Gets or sets the stack group
     */
    stackGroup: string;
    /**
     * Gets or sets the value field.
     */
    valueField?: string;
    /**
     * Gets or sets the actual rectangles for the bars.
     */
    protected actualBarRectangles?: OxyRect[];
    /**
     * Gets the nearest point.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the legend.
     */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Sets default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Updates the axes to include the max and min of this series.
     * @internal
     */
    updateAxisMaxMin(): void;
    /**
     * Computes the actual base value.
     */
    protected computeActualBaseLine(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Gets the tracker text.
     */
    protected getTrackerText(barItem: BarItem, item: any, categoryIndex: number): string | undefined;
    /**
     * Checks if the bar item is valid.
     */
    protected isValid(item: BarItem): boolean;
    /**
     * Renders the bar/column item.
     */
    protected renderItem(rc: IRenderContext, barValue: number, categoryValue: number, actualBarWidth: number, item: BarItem, rect: OxyRect): Promise<void>;
    /**
     * Renders the series on the specified render context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Updates from data fields.
     */
    protected updateFromDataFields(): boolean;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=BarSeries.d.ts.map