import { type BarItemBase, BarSeriesBase, type CreateBarSeriesBaseOptions, EdgeRenderingMode, type IRenderContext, type IStackableSeries, LabelPlacement, type LabelStringFormatterType, type OxyColor, type OxyRect, type ScreenPoint, TrackerHitResult, type TrackerStringFormatterArgs } from '../..';
/**
 * Represents an item in an IntervalBarSeries.
 */
export interface IntervalBarItem extends BarItemBase {
    /**
     * The color.
     */
    color: OxyColor;
    /**
     * The end value.
     */
    end: number;
    /**
     * The start value.
     */
    start: number;
    /**
     * The title.
     */
    title?: string;
}
export declare const DefaultIntervalBarItemOptions: IntervalBarItem;
export declare function newIntervalBarItem(item: Partial<IntervalBarItem>): IntervalBarItem & Partial<IntervalBarItem>;
export interface IntervalBarSeriesTrackerStringFormatterArgs extends TrackerStringFormatterArgs {
    readonly item?: IntervalBarItem;
    readonly categoryTitle?: string;
    readonly categoryValue?: string;
    readonly valueTitle?: string;
}
export type IntervalBarSeriesTrackerStringFormatterType = (args: IntervalBarSeriesTrackerStringFormatterArgs) => string | undefined;
export interface CreateIntervalBarSeriesOptions extends CreateBarSeriesBaseOptions {
    colorField?: string;
    endField?: string;
    fillColor?: OxyColor;
    startField?: string;
    trackerStringFormatter?: IntervalBarSeriesTrackerStringFormatterType;
}
export declare const DefaultIntervalBarSeriesOptions: CreateIntervalBarSeriesOptions;
export declare const ExtendedDefaultIntervalBarSeriesOptions: {
    colorField?: string | undefined;
    endField?: string | undefined;
    fillColor?: string | undefined;
    startField?: string | undefined;
    trackerStringFormatter?: import('../..').TrackerStringFormatterType | IntervalBarSeriesTrackerStringFormatterType | undefined;
    barWidth?: number | undefined;
    strokeColor?: string | undefined;
    strokeThickness?: number | undefined;
    labelColor?: string | undefined;
    labelMargin?: number | undefined;
    labelAngle?: number | undefined;
    labelPlacement?: LabelPlacement | undefined;
    labelStringFormatter?: LabelStringFormatterType | undefined;
    items?: BarItemBase[] | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('../..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a series for bar charts defined by to/from values.
 */
export declare class IntervalBarSeries extends BarSeriesBase<IntervalBarItem> implements IStackableSeries {
    /**
     * The default tracker formatter
     */
    static readonly DefaultTrackerStringFormatter: IntervalBarSeriesTrackerStringFormatterType;
    /**
     * The default fill color.
     */
    private _defaultFillColor;
    /**
     * Initializes a new instance of the IntervalBarSeries class.
     */
    constructor(opt?: CreateIntervalBarSeriesOptions);
    getElementName(): string;
    /**
     * A format function used for the tracker. The default depends on the series.
     * The arguments for the formatter may be different for each type of series. See the documentation.
     */
    trackerStringFormatter?: IntervalBarSeriesTrackerStringFormatterType;
    /**
     * Gets the actual fill color.
     */
    get actualFillColor(): OxyColor;
    /**
     * Gets or sets the color field.
     */
    colorField?: string;
    /**
     * Gets or sets the color field.
     */
    endField?: string;
    /**
     * Gets or sets the default color of the interior of the Maximum bars.
     */
    fillColor: OxyColor;
    readonly isStacked = true;
    readonly overlapsStack = true;
    /**
     * Gets or sets the label formatter.
     */
    labelStringFormatter: LabelStringFormatterType;
    /**
     * Gets the stack group.
     */
    readonly stackGroup = "";
    /**
     * Gets or sets the color field.
     */
    startField?: string;
    /**
     * Gets or sets the actual rectangles for the maximum bars.
     */
    protected actualBarRectangles: OxyRect[];
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the legend on the specified rendering context.
     * @param rc The rendering context.
     * @param legendBox The bounding box of the legend.
     */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Sets the default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Checks if the provided item is valid.
     * @param item The item to check.
     * @returns True if the item is valid, otherwise false.
     */
    protected isValid(item: IntervalBarItem): boolean;
    /**
     * Renders the series on the specified rendering context.
     * @param rc The rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Updates from data fields.
     */
    protected updateFromDataFields(): boolean;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=IntervalBarSeries.d.ts.map