import { type CreateDataPointSeriesOptions, type DataPoint, DataPointSeries, EdgeRenderingMode, type IRenderContext, type OxyColor, type OxyRect, type PlotModelSerializeOptions, type ScreenPoint, TrackerHitResult } from '../..';
export interface CreateLinearBarSeriesOptions extends CreateDataPointSeriesOptions {
    fillColor?: OxyColor;
    barWidth?: number;
    strokeColor?: OxyColor;
    strokeThickness?: number;
    negativeFillColor?: OxyColor;
    negativeStrokeColor?: OxyColor;
    baseValue?: number;
    baseLine?: number;
}
export declare const DefaultLinearBarSeriesOptions: CreateLinearBarSeriesOptions;
export declare const ExtendedDefaultLinearBarSeriesOptions: {
    fillColor?: string | undefined;
    barWidth?: number | undefined;
    strokeColor?: string | undefined;
    strokeThickness?: number | undefined;
    negativeFillColor?: string | undefined;
    negativeStrokeColor?: string | undefined;
    baseValue?: number | undefined;
    baseLine?: number | undefined;
    points?: DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('../..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('../..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('../..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a series to display bars in a linear axis
 */
export declare class LinearBarSeries extends DataPointSeries {
    /**
     * The rendered rectangles.
     */
    private readonly _rectangles;
    /**
     * The indexes matching rendered rectangles.
     */
    private readonly _rectanglesPointIndexes;
    /**
     * The default color.
     */
    private _defaultColor;
    /**
     * Initializes a new instance of the LinearBarSeries class.
     */
    constructor(opt?: CreateLinearBarSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the color of the interior of the bars.
     */
    fillColor: OxyColor;
    /**
     * Gets or sets the width of the bars.
     */
    barWidth: number;
    /**
     * Gets or sets the thickness of the curve.
     */
    strokeThickness: number;
    /**
     * Gets or sets the color of the border around the bars.
     */
    strokeColor: OxyColor;
    /**
     * Gets or sets the color of the interior of the bars when the value is negative.
     */
    negativeFillColor: OxyColor;
    /**
     * Gets or sets the color of the border around the bars when the value is negative.
     */
    negativeStrokeColor: OxyColor;
    /**
     * Gets the actual color.
     */
    get actualColor(): OxyColor;
    /**
     * Gets or sets the base value. Default value is 0.
     */
    baseValue: number;
    /**
     * Gets or sets the base value.
     */
    baseLine: number;
    private _actualBaseLine;
    /**
     * Gets or sets the actual baseline.
     */
    get actualBaseLine(): number;
    set actualBaseLine(value: number);
    /**
     * Gets the nearest point.
     * @param point The point.
     * @param interpolate interpolate if set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the series on the specified rendering context.
     * @param rc The rendering context.
     */
    render(rc: IRenderContext): Promise<void>;
    /** Renders the legend symbol for the line series on the specified rendering context. */
    renderLegend(rc: IRenderContext, legendBox: OxyRect): Promise<void>;
    /**
     * Sets default values from the plot model.
     * @internal
     * */
    setDefaultValues(): void;
    /**
     * Updates the axes to include the max and min of this series.
     * @internal
     * */
    updateAxisMaxMin(): void;
    /** Computes the actual base value. */
    protected computeActualBaseLine(): void;
    /**
     * Find the index of a rectangle that contains the specified point.
     * @param point the target point
     * @returns the rectangle index
     */
    private findRectangleIndex;
    /** Renders the series bars. */
    private renderBars;
    /**
     * Computes the bar width.
     * @param actualPoints The list of points.
     * @returns The bars width.
     */
    private getBarWidth;
    /**
     * Gets the colors used to draw a bar.
     * @param y The point y value
     * @returns The bar colors
     */
    private getBarColors;
    protected getElementDefaultValues(): any;
    toJSON(opt?: PlotModelSerializeOptions): any;
}
//# sourceMappingURL=LinearBarSeries.d.ts.map