import { type CreateXYAxisSeriesOptions, type DataPoint, type ScreenPoint, TrackerHitResult, XYAxisSeries } from '..';
export interface CreateDataPointSeriesOptions extends CreateXYAxisSeriesOptions {
    points?: DataPoint[];
    canTrackerInterpolatePoints?: boolean;
    dataFieldX?: string;
    dataFieldY?: string;
    mapping?: (item: any) => DataPoint;
}
export declare const DefaultDataPointSeriesOptions: CreateDataPointSeriesOptions;
export declare const ExtendedDefaultDataPointSeriesOptions: {
    points?: DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: CreateXYAxisSeriesOptions;
};
/**
 * Provides an abstract base class for series that contain a collection of DataPoints.
 */
export declare abstract class DataPointSeries extends XYAxisSeries {
    protected constructor(opt?: CreateDataPointSeriesOptions);
    /**
     * The list of data points.
     */
    private readonly _points;
    /**
     * The data points from the items source.
     */
    private _itemsSourcePoints;
    /**
     * A value indicating whether the tracker can interpolate points.
     */
    canTrackerInterpolatePoints: boolean;
    /**
     * The data field X. The default is null.
     */
    dataFieldX?: string;
    /**
     * The data field Y. The default is null.
     */
    dataFieldY?: string;
    /**
     * The delegate used to map from ItemsSeries.ItemsSource to the ActualPoints. The default is null.
     */
    mapping?: (item: any) => DataPoint;
    /**
     * Gets the list of points.
     */
    get points(): DataPoint[];
    /**
     * Gets the list of points that should be rendered.
     */
    protected get actualPoints(): DataPoint[];
    /**
     * Gets the point on the series that is nearest the specified point.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Updates the data.
     * @internal
     */
    updateData(): void;
    /**
     * Updates the maximum and minimum values of the series.
     * @internal
     */
    updateMaxMin(): void;
    /**
     * Gets the item at the specified index.
     */
    protected getItem(i: number): any;
    /**
     * Clears or creates the itemsSourcePoints list.
     */
    private clearItemsSourcePoints;
    /**
     * Updates the points from the ItemsSource.
     */
    private updateItemsSourcePoints;
    protected convertToDataPoint(item: any): DataPoint | undefined;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=DataPointSeries.d.ts.map