import { type CreateLineSeriesOptions, LineSeries } from '..';
export interface CreateFunctionSeriesOptions extends CreateLineSeriesOptions {
    f?: (x: number) => number;
    x0?: number;
    x1?: number;
    dx?: number;
    n?: number;
    fx?: (t: number) => number;
    fy?: (t: number) => number;
    t0?: number;
    t1?: number;
    dt?: number;
}
export declare const ExtendedDefaultFunctionSeriesOptions: {
    color?: string | undefined;
    brokenLineColor?: string | undefined;
    brokenLineStyle?: import('..').LineStyle | undefined;
    brokenLineThickness?: number | undefined;
    dashes?: number[] | undefined;
    decimator?: ((points: import('..').ScreenPoint[], result: import('..').ScreenPoint[]) => void) | undefined;
    labelStringFormatter?: import('..').LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    lineStyle?: import('..').LineStyle | undefined;
    lineLegendPosition?: import('..').LineLegendPosition | undefined;
    markerFill?: string | undefined;
    markerOutline?: import('..').ScreenPoint[] | undefined;
    markerResolution?: number | undefined;
    markerSize?: number | undefined;
    markerStroke?: string | undefined;
    markerStrokeThickness?: number | undefined;
    markerType?: import('..').MarkerType | undefined;
    minimumSegmentLength?: number | undefined;
    interpolationAlgorithm?: import('..').IInterpolationAlgorithm | undefined;
    strokeThickness?: number | undefined;
    points?: import('..').DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => import('..').DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a line series that generates its dataset from a function.
 *
 * Remarks:
 * - Define `f(x)` and make a plot on the range `[x0,x1]`
 * - or define `x(t)` and `y(t)` and make a plot on the range `[t0,t1]`
 */
export declare class FunctionSeries extends LineSeries {
    constructor(opt: CreateFunctionSeriesOptions);
    getElementName(): string;
    static fromDx(f: (x: number) => number, x0: number, x1: number, dx: number, title?: string): FunctionSeries;
    static fromN(f: (x: number) => number, x0: number, x1: number, n: number, title?: string): FunctionSeries;
    static fromFxFyDt(fx: (t: number) => number, fy: (t: number) => number, t0: number, t1: number, dt: number, title?: string): FunctionSeries;
    static fromFxFyN(fx: (t: number) => number, fy: (t: number) => number, t0: number, t1: number, n: number, title?: string): FunctionSeries;
    /**
     * Initializes a new instance of the FunctionSeries class using a function f(x).
     * @param f The function f(x).
     * @param x0 The start x value.
     * @param x1 The end x value.
     * @param dx The increment in x.
     */
    private f1;
    /**
     * Initializes a new instance of the FunctionSeries class using a function f(x).
     * @param f The function f(x).
     * @param x0 The start x value.
     * @param x1 The end x value.
     * @param n The number of points.
     */
    f2(f: (x: number) => number, x0: number, x1: number, n: number): void;
    /**
     * Initializes a new instance of the FunctionSeries class using functions x(t) and y(t).
     * @param fx The function x(t).
     * @param fy The function y(t).
     * @param t0 The start t parameter.
     * @param t1 The end t parameter.
     * @param dt The increment in t.
     */
    private f3;
    /**
     * Initializes a new instance of the FunctionSeries class using functions x(t) and y(t).
     * @param fx The function x(t).
     * @param fy The function y(t).
     * @param t0 The start t parameter.
     * @param t1 The end t parameter.
     * @param n The number of points.
     */
    private f4;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=FunctionSeries.d.ts.map