import { type CreateLineSeriesOptions, type DataPoint, EdgeRenderingMode, type IRenderContext, LineSeries, LineStyle, MarkerType, type ScreenPoint, TrackerHitResult } from '..';
export interface CreateStairStepSeriesOptions extends CreateLineSeriesOptions {
    verticalStrokeThickness?: number;
    verticalLineStyle?: LineStyle;
}
export declare const DefaultStairStepSeriesOptions: CreateStairStepSeriesOptions;
export declare const ExtendedDefaultStairStepSeriesOptions: {
    verticalStrokeThickness?: number | undefined;
    verticalLineStyle?: LineStyle | undefined;
    color?: string | undefined;
    brokenLineColor?: string | undefined;
    brokenLineStyle?: LineStyle | undefined;
    brokenLineThickness?: number | undefined;
    dashes?: number[] | undefined;
    decimator?: ((points: ScreenPoint[], result: ScreenPoint[]) => void) | undefined;
    labelStringFormatter?: import('..').LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    lineLegendPosition?: import('..').LineLegendPosition | undefined;
    markerFill?: string | undefined;
    markerOutline?: ScreenPoint[] | undefined;
    markerResolution?: number | undefined;
    markerSize?: number | undefined;
    markerStroke?: string | undefined;
    markerStrokeThickness?: number | undefined;
    markerType?: MarkerType | undefined;
    minimumSegmentLength?: number | undefined;
    interpolationAlgorithm?: import('..').IInterpolationAlgorithm | undefined;
    strokeThickness?: number | undefined;
    points?: DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a series for stair step graphs.
 */
export declare class StairStepSeries extends LineSeries {
    /**
     * Initializes a new instance of the StairStepSeries class.
     */
    constructor(opt?: CreateStairStepSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the stroke thickness of the vertical line segments.
     */
    verticalStrokeThickness: number;
    /**
     * Gets or sets the line style of the vertical line segments.
     */
    verticalLineStyle: LineStyle;
    /**
     * Gets the nearest point.
     * @param point The point.
     * @param interpolate interpolate if set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    render(rc: IRenderContext): Promise<void>;
    private findNextValidSegment;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=StairStepSeries.d.ts.map