import { type CreateLineSeriesOptions, type IRenderContext, LineSeries, LineStyle, type OxyColor, type ScreenPoint } from '..';
export interface CrateThreeColorLineSeriesOptions extends CreateLineSeriesOptions {
    colorLo?: OxyColor;
    colorHi?: OxyColor;
    limitLo?: number;
    limitHi?: number;
    dashesLo?: number[];
    dashesHi?: number[];
    lineStyleLo?: LineStyle;
    lineStyleHi?: LineStyle;
}
export declare const DefaultThreeColorLineSeriesOptions: CrateThreeColorLineSeriesOptions;
export declare const ExtendedDefaultThreeColorLineSeriesOptions: {
    colorLo?: string | undefined;
    colorHi?: string | undefined;
    limitLo?: number | undefined;
    limitHi?: number | undefined;
    dashesLo?: number[] | undefined;
    dashesHi?: number[] | undefined;
    lineStyleLo?: LineStyle | undefined;
    lineStyleHi?: LineStyle | undefined;
    color?: string | undefined;
    brokenLineColor?: string | undefined;
    brokenLineStyle?: LineStyle | undefined;
    brokenLineThickness?: number | undefined;
    dashes?: number[] | undefined;
    decimator?: ((points: ScreenPoint[], result: ScreenPoint[]) => void) | undefined;
    labelStringFormatter?: import('..').LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    lineLegendPosition?: import('..').LineLegendPosition | undefined;
    markerFill?: string | undefined;
    markerOutline?: ScreenPoint[] | undefined;
    markerResolution?: number | undefined;
    markerSize?: number | undefined;
    markerStroke?: string | undefined;
    markerStrokeThickness?: number | undefined;
    markerType?: import('..').MarkerType | undefined;
    minimumSegmentLength?: number | undefined;
    interpolationAlgorithm?: import('..').IInterpolationAlgorithm | undefined;
    strokeThickness?: number | undefined;
    points?: import('..').DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => import('..').DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a three-color line series.
 */
export declare class ThreeColorLineSeries extends LineSeries {
    /**
     * The default low color.
     */
    private defaultColorLo;
    /**
     * The default hi color.
     */
    private defaultColorHi;
    /**
     * Initializes a new instance of the ThreeColorLineSeries class.
     */
    constructor(opt?: CrateThreeColorLineSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the color for the part of the line that is below the limit.
     */
    colorLo: OxyColor;
    /**
     * Gets or sets the color for the part of the line that is above the limit.
     */
    colorHi: OxyColor;
    /**
     * Gets the actual low color.
     */
    get actualColorLo(): OxyColor;
    /**
     * Gets the actual hi color.
     */
    get actualColorHi(): OxyColor;
    /**
     * Gets or sets the high limit.
     */
    limitHi: number;
    /**
     * Gets or sets the low limit.
     */
    limitLo: number;
    /**
     * Gets or sets the dash array for the rendered line that is above the limit (overrides LineStyle).
     */
    dashesHi?: number[];
    /**
     * Gets or sets the dash array for the rendered line that is below the limit (overrides LineStyle).
     */
    dashesLo?: number[];
    /**
     * Gets or sets the line style for the part of the line that is above the limit.
     */
    lineStyleHi: LineStyle;
    /**
     * Gets or sets the line style for the part of the line that is below the limit.
     */
    lineStyleLo: LineStyle;
    /**
     * Gets the actual line style for the part of the line that is above the limit.
     */
    get actualLineStyleHi(): LineStyle;
    /**
     * Gets the actual line style for the part of the line that is below the limit.
     */
    get actualLineStyleLo(): LineStyle;
    /**
     * Gets the actual dash array for the line that is above the limit.
     */
    get actualDashArrayHi(): number[] | undefined;
    /**
     * Gets the actual dash array for the line that is below the limit.
     */
    get actualDashArrayLo(): number[] | undefined;
    /**
     * Sets the default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Renders the line.
     * @param rc The render context.
     * @param pointsToRender The points to render.
     */
    protected renderLine(rc: IRenderContext, pointsToRender: ScreenPoint[]): Promise<void>;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=ThreeColorLineSeries.d.ts.map