import { AreaRenderContext, AreaSeries, type CreateAreaSeriesOptions, type DataPoint, type IRenderContext, LineStyle, type OxyColor, type ScreenPoint, TrackerHitResult } from '..';
export interface CreateTwoColorAreaSeriesOptions extends CreateAreaSeriesOptions {
    color2?: OxyColor;
    fill2?: OxyColor;
    lineStyle2?: LineStyle;
    markerFill2?: OxyColor;
    markerStroke2?: OxyColor;
    limit?: number;
}
export declare const DefaultTwoColorAreaSeriesOptions: CreateTwoColorAreaSeriesOptions;
export declare const ExtendedDefaultTwoColorAreaSeriesOptions: {
    color2?: string | undefined;
    fill2?: string | undefined;
    lineStyle2?: LineStyle | undefined;
    markerFill2?: string | undefined;
    markerStroke2?: string | undefined;
    limit?: number | undefined;
    constantY2?: number | undefined;
    dataFieldX2?: string | undefined;
    dataFieldY2?: string | undefined;
    fill?: string | undefined;
    reverse2?: boolean | undefined;
    points2?: DataPoint[] | undefined;
    color?: string | undefined;
    brokenLineColor?: string | undefined;
    brokenLineStyle?: LineStyle | undefined;
    brokenLineThickness?: number | undefined;
    dashes?: number[] | undefined;
    decimator?: ((points: ScreenPoint[], result: ScreenPoint[]) => void) | undefined;
    labelStringFormatter?: import('..').LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    lineLegendPosition?: import('..').LineLegendPosition | undefined;
    markerFill?: string | undefined;
    markerOutline?: ScreenPoint[] | undefined;
    markerResolution?: number | undefined;
    markerSize?: number | undefined;
    markerStroke?: string | undefined;
    markerStrokeThickness?: number | undefined;
    markerType?: import('..').MarkerType | undefined;
    minimumSegmentLength?: number | undefined;
    interpolationAlgorithm?: import('..').IInterpolationAlgorithm | undefined;
    strokeThickness?: number | undefined;
    points?: DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a two-color area series.
 */
export declare class TwoColorAreaSeries extends AreaSeries {
    /**
     * The default second color.
     */
    private _defaultColor2;
    /**
     * The collection of points above the limit.
     */
    private _abovePoints;
    /**
     * The collection of points below the limit.
     */
    private _belowPoints;
    /**
     * Start index of a visible rendering window for markers.
     */
    private _markerStartIndex;
    /**
     * Initializes a new instance of the TwoColorAreaSeries class.
     */
    constructor(opt?: CreateTwoColorAreaSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the area fill color below the limit line.
     */
    fill2: OxyColor;
    /**
     * Gets the actual fill color below the limit line.
     */
    get actualFill2(): OxyColor;
    /**
     * Gets the actual second color.
     */
    get actualColor2(): OxyColor;
    /**
     * Gets or sets the dash array for the rendered line that is below the limit (overrides LineStyle).
     */
    dashes2?: number[];
    /**
     * Gets or sets the line style for the part of the line that is below the limit.
     */
    lineStyle2: LineStyle;
    /**
     * Gets the actual line style for the part of the line that is below the limit.
     */
    get actualLineStyle2(): LineStyle;
    /**
     * Gets the actual dash array for the line that is below the limit.
     */
    get actualDashArray2(): number[] | undefined;
    /**
     * Gets or sets the marker fill color which is below the limit line. The default is OxyColors.Automatic.
     */
    markerFill2: OxyColor;
    /**
     * Gets or sets the marker stroke which is below the limit line. The default is OxyColors.Automatic.
     */
    markerStroke2: OxyColor;
    /**
     * Gets or sets a baseline for the series.
     */
    limit: number;
    /**
     * Gets the nearest point.
     * @param point The point.
     * @param interpolate Interpolate if set to true.
     * @returns A TrackerHitResult for the current hit.
     */
    getNearestPoint(point: ScreenPoint, interpolate: boolean): TrackerHitResult | undefined;
    /**
     * Renders the series on the specified render context.
     * @param rc The render context.
     */
    render(rc: IRenderContext): Promise<void>;
    /**
     * Sets the default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * The update data.
     * @internal
     */
    updateData(): void;
    /**
     * Renders a chunk of points on the screen.
     * @param context Render context.
     * @param points Screen points.
     * @returns The list of resampled points.
     */
    protected renderScreenPoints(context: AreaRenderContext, points: ScreenPoint[]): Promise<ScreenPoint[]>;
    /**
     * Splits a collection of points into two collections based on their Y value.
     * @param source A collection of points to split.
     */
    private splitPoints;
    /**
     * Gets the screen points when baseline is used.
     * @param source The list of polygon screen points.
     * @param baseline Baseline Y value for the polygon.
     * @returns A sequence of DataPoint.
     */
    private getConstantScreenPoints2;
    /**
     * Gets interpolated X coordinate for given Y on a straight line
     * between two points.
     * @param a First point.
     * @param b Second point.
     * @param y Y coordinate.
     * @returns Corresponding X coordinate.
     */
    private getInterpolatedX;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=TwoColorAreaSeries.d.ts.map