import { type CreateLineSeriesOptions, type IRenderContext, LineSeries, LineStyle, type OxyColor, type ScreenPoint } from '..';
export interface CreateTwoColorLineSeriesOptions extends CreateLineSeriesOptions {
    color2?: OxyColor;
    limit?: number;
}
export declare const DefaultTwoColorLineSeriesOptions: CreateTwoColorLineSeriesOptions;
export declare const ExtendedDefaultTwoColorLineSeriesOptions: {
    color2?: string | undefined;
    limit?: number | undefined;
    color?: string | undefined;
    brokenLineColor?: string | undefined;
    brokenLineStyle?: LineStyle | undefined;
    brokenLineThickness?: number | undefined;
    dashes?: number[] | undefined;
    decimator?: ((points: ScreenPoint[], result: ScreenPoint[]) => void) | undefined;
    labelStringFormatter?: import('..').LabelStringFormatterType | undefined;
    labelMargin?: number | undefined;
    lineJoin?: import('..').LineJoin | undefined;
    lineStyle?: LineStyle | undefined;
    lineLegendPosition?: import('..').LineLegendPosition | undefined;
    markerFill?: string | undefined;
    markerOutline?: ScreenPoint[] | undefined;
    markerResolution?: number | undefined;
    markerSize?: number | undefined;
    markerStroke?: string | undefined;
    markerStrokeThickness?: number | undefined;
    markerType?: import('..').MarkerType | undefined;
    minimumSegmentLength?: number | undefined;
    interpolationAlgorithm?: import('..').IInterpolationAlgorithm | undefined;
    strokeThickness?: number | undefined;
    points?: import('..').DataPoint[] | undefined;
    canTrackerInterpolatePoints?: boolean | undefined;
    dataFieldX?: string | undefined;
    dataFieldY?: string | undefined;
    mapping?: ((item: any) => import('..').DataPoint) | undefined;
    xAxisKey?: string | undefined;
    yAxisKey?: string | undefined;
    itemsSource?: any[] | undefined;
    background?: string | undefined;
    isVisible?: boolean | undefined;
    title?: string | undefined;
    legendKey?: string | undefined;
    seriesGroupName?: string | undefined;
    renderInLegend?: boolean | undefined;
    trackerStringFormatter?: import('..').TrackerStringFormatterType | undefined;
    trackerKey?: string | undefined;
    font?: string | undefined;
    fontSize?: number | undefined;
    fontWeight?: number | undefined;
    tag?: any;
    textColor?: string | undefined;
    edgeRenderingMode?: import('..').EdgeRenderingMode | undefined;
    toolTip?: string | undefined;
    selectable?: boolean | undefined;
    selectionMode?: import('..').SelectionMode | undefined;
    DefaultXYAxisSeriesOptions: import('..').CreateXYAxisSeriesOptions;
};
/**
 * Represents a two-color line series.
 */
export declare class TwoColorLineSeries extends LineSeries {
    /**
     * The default second color.
     */
    private _defaultColor2;
    /**
     * Initializes a new instance of the TwoColorLineSeries class.
     */
    constructor(opt?: CreateTwoColorLineSeriesOptions);
    getElementName(): string;
    /**
     * Gets or sets the color for the part of the line that is below the limit.
     */
    color2: OxyColor;
    /**
     * Gets the actual second color.
     */
    get actualColor2(): OxyColor;
    /**
     * Gets or sets the limit.
     */
    limit: number;
    /**
     * Sets the default values.
     * @internal
     */
    setDefaultValues(): void;
    /**
     * Renders the line.
     * @param rc The render context.
     * @param pointsToRender The points to render.
     */
    protected renderLine(rc: IRenderContext, pointsToRender: ScreenPoint[]): Promise<void>;
    protected getElementDefaultValues(): any;
}
//# sourceMappingURL=TwoColorLineSeries.d.ts.map