/** Specifies the behaviour for handling elements which cannot be assigned to any bin. */
export declare enum BinningOutlierMode {
    /** Throws an error if any element cannot be assigned to any bin. */
    RejectOutliers = 0,
    /** Counts outliers when computing statistics. */
    IgnoreOutliers = 1,
    /** Ignores outliers when computing statistics. */
    CountOutliers = 2
}
/** Specifies the type of bounds used for binning. */
export declare enum BinningIntervalType {
    /** Bins have an incusive lower bound. */
    InclusiveLowerBound = 0,
    /** Bins have an incusive upper bound. */
    InclusiveUpperBound = 1
}
/** Specifies the behaviour for handing extreme values which would be excluded by an exclusive bound. */
export declare enum BinningExtremeValueMode {
    /** Extreme values should be excluded if they do not fall on an inclusive bound. */
    ExcludeExtremeValues = 0,
    /** Extreme values should always be included. */
    IncludeExtremeValues = 1
}
/** Represents options for methods that perform binning. */
export declare class BinningOptions {
    readonly outlierMode: BinningOutlierMode;
    readonly intervalType: BinningIntervalType;
    readonly extremeValuesMode: BinningExtremeValueMode;
    /** Initializes a new instance of the BinningOptions class. */
    constructor(outlierMode: BinningOutlierMode, intervalType: BinningIntervalType, extremeValuesMode: BinningExtremeValueMode);
}
//# sourceMappingURL=BinningOptions.d.ts.map