import { BinningOptions, type HistogramItem } from '..';
/**
 * Provides methods to collect data samples into bins for use with a HistogramSeries.
 */
export declare class HistogramHelpers {
    /**
     * Generates a list of binCount bin breaks, uniformly distributed between start and end.
     * @param start The inclusive lower-bound of the first bin.
     * @param end The exclusive upper-bound of the last bin, which must be strictly greater than start.
     * @param binCount The number of bins to create.
     * @returns An array containing the breaks between bins of uniform size.
     */
    static createUniformBins(start: number, end: number, binCount: number): number[];
    /**
     * Collects samples into tightly packed bins (HistogramItem) defined by binBreaks.
     * @param samples The samples to collect into bins.
     * @param binBreaks The start and end values for the bins.
     * @param binningOptions The binning options to use.
     * @returns A list of HistogramItem corresponding to the generated bins with areas computed from the proportion of samples placed within.
     */
    static collect(samples: number[], binBreaks: number[], binningOptions: BinningOptions): HistogramItem[];
    private static binarySearch;
}
//# sourceMappingURL=HistogramHelpers.d.ts.map