import { PlotModel } from '..';
/**
 * Provides utility functions for PlotModel used in examples.
 */
export declare class PlotModelUtilities {
    private static readonly XAXIS_KEY;
    private static readonly YAXIS_KEY;
    /**
     * Lists all XYAxisSeries from the core library that are NOT reversible.
     */
    private static readonly NonReversibleSeriesTypes;
    /**
     * Lists all Annotations that need axes and are NOT reversible.
     */
    private static readonly NonReversibleDataSpaceAnnotationTypes;
    /**
     * Lists all XYAxisSeries from the core library that are NOT transposable.
     */
    private static readonly NonTransposableSeriesTypes;
    /**
     * Lists all Annotations that need axes and are NOT transposable.
     */
    private static readonly NonTransposableDataSpaceAnnotationTypes;
    /**
     * Returns a value indicating whether a plot model is reversible.
     * @param model The plot model.
     * @returns True if the plot model in reversible; false otherwise.
     */
    static isReversible(model: PlotModel): boolean;
    /**
     * Returns a value indicating whether a plot model is transposable.
     * @param model The plot model.
     * @returns True if the plot model in transposable; false otherwise.
     */
    static isTransposable(model: PlotModel): boolean;
    /**
     * Reverses the X Axis of a PlotModel. The given PlotModel is mutated and returned for convenience.
     * @param model The PlotModel.
     * @returns The PlotModel with reversed X Axis.
     */
    static reverseXAxis(model: PlotModel): PlotModel;
    /**
     * Reverses the Y Axis of a PlotModel. The given PlotModel is mutated and returned for convenience.
     * @param model The PlotModel.
     * @returns The PlotModel with reversed Y Axis.
     */
    static reverseYAxis(model: PlotModel): PlotModel;
    /**
     * Reverses all axes of a PlotModel. The given PlotModel is mutated and returned for convenience.
     * @param model The PlotModel.
     * @returns The PlotModel with reversed axes.
     */
    static reverseAllAxes(model: PlotModel): PlotModel;
    /**
     * Transposes a PlotModel. The given PlotModel is mutated and returned for convenience.
     * @param model The PlotModel.
     * @returns The transposed PlotModel.
     */
    static transpose(model: PlotModel): PlotModel;
}
//# sourceMappingURL=PlotModelUtilities.d.ts.map